{
 "cells": [
  {
   "attachments": {},
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Introduction\n",
    "This package is in an early development stage. Use it with care and you should expect things to break unannounced until we release a version `1.0.0`.\n",
    "\n",
    "You can use altair_tiles to add tiles from any xyz tile provider such as OpenStreetMap to your Altair chart. It is a counterpart to the amazing [contextily](https://github.com/geopandas/contextily) package which provides this functionality for [matplotlib](https://matplotlib.org/).\n",
    "\n",
    "For a general introduction to plotting geographic data with Altair, see [Geoshape - Vega-Altair](https://altair-viz.github.io/user_guide/marks/geoshape.html) and [Specifying Data - Vega-Altair](https://altair-viz.github.io/user_guide/data.html#spatial-data).\n",
    "\n",
    "## Installation\n",
    "```bash\n",
    "pip install altair_tiles\n",
    "# or\n",
    "conda install -c conda-forge altair_tiles\n",
    "```\n"
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Basic example\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {},
   "outputs": [],
   "source": [
    "import altair as alt\n",
    "import altair_tiles as til\n",
    "import geopandas as gpd"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-95c1fc4a3fc246d583b76c81b936362f.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-95c1fc4a3fc246d583b76c81b936362f.vega-embed details,\n",
       "  #altair-viz-95c1fc4a3fc246d583b76c81b936362f.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-95c1fc4a3fc246d583b76c81b936362f\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-95c1fc4a3fc246d583b76c81b936362f\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-95c1fc4a3fc246d583b76c81b936362f\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.15.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.15.1\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}}, \"layer\": [{\"data\": {\"sequence\": {\"start\": 0, \"stop\": 20, \"as\": \"a\"}, \"name\": \"tile_list\"}, \"mark\": {\"type\": \"image\", \"clip\": true, \"height\": {\"expr\": \"tile_size + 1\"}, \"width\": {\"expr\": \"tile_size + 1\"}}, \"encoding\": {\"url\": {\"field\": \"url\", \"type\": \"nominal\"}, \"x\": {\"field\": \"x\", \"scale\": null, \"type\": \"quantitative\"}, \"y\": {\"field\": \"y\", \"scale\": null, \"type\": \"quantitative\"}}, \"transform\": [{\"calculate\": \"sequence(0, 20)\", \"as\": \"b\"}, {\"flatten\": [\"b\"]}, {\"calculate\": \"'https://tile.openstreetmap.org/' + zoom_ceil + '/' + ((datum.a + dii_floor + max_one_side_tiles_count) % max_one_side_tiles_count) + '/' + (datum.b + djj_floor) + '.png'\", \"as\": \"url\"}, {\"calculate\": \"datum.a * tile_size + dx + (tile_size / 2)\", \"as\": \"x\"}, {\"calculate\": \"datum.b * tile_size + dy + (tile_size / 2)\", \"as\": \"y\"}, {\"filter\": \"datum.x < (width + tile_size / 2) && datum.y < (height + tile_size / 2)\"}, {\"filter\": \"((datum.a + dii_floor + max_one_side_tiles_count) % max_one_side_tiles_count) >= 0 && (datum.b + djj_floor) >= 0 && ((datum.a + dii_floor + max_one_side_tiles_count) % max_one_side_tiles_count) <= (max_one_side_tiles_count - 1) && (datum.b + djj_floor) <= (max_one_side_tiles_count - 1)\"}]}, {\"data\": {\"name\": \"data-c7db1c0288b32aa6b2fb19d9aea5a1f8\"}, \"mark\": {\"type\": \"geoshape\", \"fillOpacity\": 0.1, \"stroke\": \"green\", \"strokeWidth\": 2}, \"projection\": {\"type\": \"mercator\"}}, {\"data\": {\"name\": \"empty\"}, \"mark\": {\"type\": \"text\", \"align\": \"left\", \"dx\": 3, \"dy\": -8, \"text\": \"(C) OpenStreetMap contributors\"}, \"encoding\": {\"x\": {\"value\": 0}, \"y\": {\"value\": {\"expr\": \"height\"}}}}], \"height\": 400, \"params\": [{\"name\": \"base_tile_size\", \"value\": 256}, {\"name\": \"pr_scale\", \"expr\": \"geoScale('projection')\"}, {\"name\": \"zoom_level\", \"expr\": \"log((2 * PI * pr_scale) / base_tile_size) / log(2)\"}, {\"name\": \"zoom_ceil\", \"expr\": \"ceil(zoom_level)\"}, {\"name\": \"max_one_side_tiles_count\", \"expr\": \"pow(2, zoom_ceil)\"}, {\"name\": \"tile_size\", \"expr\": \"base_tile_size * pow(2, zoom_level - zoom_ceil)\"}, {\"name\": \"base_point\", \"expr\": \"invert('projection', [0, 0])\"}, {\"name\": \"dii\", \"expr\": \"(base_point[0] + 180) / 360 * max_one_side_tiles_count\"}, {\"name\": \"dii_floor\", \"expr\": \"floor(dii)\"}, {\"name\": \"dx\", \"expr\": \"(dii_floor - dii) * tile_size\"}, {\"name\": \"djj\", \"expr\": \"(1 - log(tan(base_point[1] * PI / 180) + 1 / cos(base_point[1] * PI / 180)) / PI) / 2 * max_one_side_tiles_count\"}, {\"name\": \"djj_floor\", \"expr\": \"floor(djj)\"}, {\"name\": \"dy\", \"expr\": \"round((djj_floor - djj) * tile_size)\"}], \"width\": 600, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.15.1.json\", \"datasets\": {\"data-c7db1c0288b32aa6b2fb19d9aea5a1f8\": [{\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[33.90371119710453, -0.9500000000000001], [34.07261999999997, -1.0598199999999451], [37.69868999999994, -3.0969899999999484], [37.7669, -3.6771200000000004], [39.20222, -4.67677], [38.74053999999995, -5.9089499999999475], [38.79977000000008, -6.475660000000005], [39.44, -6.839999999999861], [39.47000000000014, -7.099999999999966], [39.19468999999998, -7.703899999999976], [39.25203000000005, -8.00780999999995], [39.18652000000009, -8.48550999999992], [39.53574000000009, -9.112369999999885], [39.94960000000003, -10.098400000000026], [40.316586229110854, -10.317097752817492], [40.31659000000002, -10.317099999999868], [39.52099999999996, -10.89688000000001], [38.42755659358775, -11.285202325081656], [37.827639999999974, -11.26878999999991], [37.471289999999954, -11.568759999999997], [36.775150994622805, -11.594537448780805], [36.51408165868426, -11.720938002166735], [35.31239790216904, -11.439146416879147], [34.55998904799935, -11.520020033415925], [34.27999999999997, -10.160000000000025], [33.940837724096525, -9.693673841980285], [33.73972000000009, -9.417149999999992], [32.75937544122132, -9.23059905358906], [32.19186486179194, -8.930358981973257], [31.556348097466497, -8.762048841998642], [31.15775133695005, -8.594578747317366], [30.740009731422095, -8.34000593035372], [30.74001549655179, -8.340007419470915], [30.199996779101696, -7.079980970898163], [29.620032179490014, -6.520015150583426], [29.419992710088167, -5.939998874539434], [29.519986606572928, -5.419978936386315], [29.339997592900346, -4.4999834122940925], [29.753512404099865, -4.452389418153302], [30.11632000000003, -4.090120000000013], [30.505539999999996, -3.5685799999999404], [30.752240000000086, -3.3593099999999936], [30.743010000000027, -3.034309999999948], [30.527660000000026, -2.807619999999986], [30.469673645761223, -2.41385475710134], [30.469670000000008, -2.4138299999999617], [30.75830895358311, -2.2872502579883687], [30.816134881317712, -1.6989140763453887], [30.419104852019245, -1.1346591121504161], [30.769860000000108, -1.0145499999999856], [31.866170000000068, -1.0273599999999306], [33.90371119710453, -0.9500000000000001]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[-8.665589565454809, 27.656425889592356], [-8.665124477564191, 27.589479071558227], [-8.684399786809053, 27.395744126896005], [-8.6872936670174, 25.881056219988906], [-11.96941891117116, 25.933352769468268], [-11.937224493853321, 23.374594224536168], [-12.874221564169575, 23.284832261645178], [-13.118754441774712, 22.771220201096256], [-12.929101935263532, 21.327070624267563], [-16.845193650773993, 21.33332347257488], [-17.06342322434257, 20.999752102130827], [-17.02042843267577, 21.422310288981578], [-17.00296179856109, 21.420734157796577], [-14.750954555713534, 21.500600083903663], [-14.630832688851072, 21.860939846274903], [-14.221167771857253, 22.31016307218816], [-13.891110398809047, 23.691009019459305], [-12.50096269372537, 24.7701162785782], [-12.03075883630163, 26.030866197203068], [-11.718219773800357, 26.104091701760623], [-11.392554897497007, 26.883423977154393], [-10.551262579785273, 26.990807603456886], [-10.189424200877582, 26.860944729107405], [-9.735343390328879, 26.860944729107405], [-9.41303748212448, 27.088476060488574], [-8.794883999049077, 27.120696316022507], [-8.817828334986672, 27.656425889592356], [-8.665589565454809, 27.656425889592356]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[29.339997592900346, -4.4999834122940925], [29.519986606572928, -5.419978936386315], [29.419992710088167, -5.939998874539434], [29.620032179490014, -6.520015150583426], [30.199996779101696, -7.079980970898163], [30.74001549655179, -8.340007419470915], [30.740009731422095, -8.34000593035372], [30.346086053190817, -8.238256524288218], [29.00291222506047, -8.407031752153472], [28.734866570762502, -8.526559340044578], [28.449871046672826, -9.164918308146085], [28.67368167492893, -9.605924981324932], [28.49606977714177, -10.789883721564046], [28.372253045370428, -11.793646742401393], [28.642417433392353, -11.971568698782315], [29.34154788586909, -12.360743910372413], [29.61600141777123, -12.178894545137311], [29.69961388521949, -13.257226657771831], [28.934285922976837, -13.248958428605135], [28.523561639121027, -12.698604424696683], [28.155108676879987, -12.272480564017897], [27.388798862423783, -12.132747491100666], [27.164419793412463, -11.608748467661075], [26.553087599399618, -11.924439792532127], [25.752309604604733, -11.784965101776358], [25.418118116973204, -11.330935967659961], [24.78316979340295, -11.238693536018964], [24.31451622894795, -11.26282642989927], [24.25715538910399, -10.951992689663657], [23.912215203555718, -10.926826267137514], [23.45679080576744, -10.867863457892483], [22.83734541188474, -11.01762175867433], [22.402798292742375, -10.993075453335692], [22.155268182064308, -11.084801120653772], [22.208753289486395, -9.894796237836509], [21.875181919042348, -9.523707777548566], [21.8018013851879, -8.90870655684298], [21.949130893652043, -8.305900974158277], [21.74645592620331, -7.920084730667149], [21.7281107927397, -7.290872491081302], [20.5147481625265, -7.2996058081386295], [20.6018229509383, -6.939317722199682], [20.091621534920648, -6.943090101756994], [20.037723016040218, -7.116361179231646], [19.41750247567316, -7.155428562044299], [19.16661339689611, -7.738183688999754], [19.01675174324967, -7.988245944860132], [18.464175652752687, -7.847014255406443], [18.13422163256905, -7.987677504104923], [17.472970004962235, -8.0685511206417], [17.08999596524717, -7.545688978712526], [16.8601908708452, -7.2222978654299865], [16.573179965896145, -6.6226445451150875], [16.326528354567046, -5.877470391466268], [13.375597364971895, -5.8642412247995495], [13.024869419006961, -5.984388929878158], [12.735171339578699, -5.965682061388499], [12.32243167486351, -6.10009246177966], [12.182336866920252, -5.789930515163839], [12.436688266660868, -5.6843038875592455], [12.468004184629736, -5.248361504745005], [12.63161176926579, -4.991271254092936], [12.995517205465177, -4.781103203961884], [13.258240187237048, -4.882957452009165], [13.600234816144678, -4.50013844159097], [14.144956088933299, -4.510008640158716], [14.209034864975223, -4.793092136253598], [14.582603794013181, -4.97023894615014], [15.170991652088444, -4.343507175314301], [15.753540073314753, -3.8551648901560966], [16.0062895036543, -3.535132744972529], [15.972803175529151, -2.7123922664536124], [16.407091912510054, -1.7409270157986825], [16.865306837642123, -1.2258163387132868], [17.523716261472856, -0.743830254726987], [17.638644646889986, -0.4248316381892465], [17.66355268725468, -0.05808399821381727], [17.826540154703252, 0.28892324462610475], [17.774191928791566, 0.8556586775710854], [17.898835483479587, 1.7418319767282782], [18.094275750407434, 2.365721543788055], [18.393792351971143, 2.90044342692822], [18.45306521980993, 3.5043858911233485], [18.54298221199778, 4.201785183118318], [18.93231245288476, 4.709506130385975], [19.46778364429315, 5.03152781821278], [20.290679152108936, 4.691677761245288], [20.927591180106276, 4.322785549329737], [21.659122755630023, 4.22434194581372], [22.405123732195538, 4.029160061047321], [22.70412356943629, 4.633050848810157], [22.841479526468106, 4.710126247573484], [23.29721398285014, 4.609693101414223], [24.410531040146253, 5.10878408448913], [24.805028924262416, 4.89724660890235], [25.12883344900328, 4.92724477784779], [25.278798455514305, 5.170408229997192], [25.650455356557472, 5.256087754737123], [26.402760857862543, 5.1508745385908705], [27.04406538260471, 5.127852688004836], [27.37422610851749, 5.233944403500061], [27.97997724784281, 4.408413397637375], [28.428993768026913, 4.287154649264494], [28.696677687298802, 4.455077215996937], [29.1590784034465, 4.389267279473231], [29.71599531425602, 4.600804755060153], [29.953500197069474, 4.173699042167684], [30.833852421715427, 3.5091716042224625], [30.83385989759381, 3.509165961110341], [30.77334679538004, 2.339883327642127], [31.174149204235817, 2.204465236821264], [30.85267011894806, 1.8493964705438088], [30.46850752129029, 1.5838054467797065], [30.086153598762706, 1.0623127303062887], [29.875778842902434, 0.5973798689763612], [29.819503208136638, -0.2053101538133717], [29.58783776217217, -0.587405694179381], [29.579466180140884, -1.3413131648856265], [29.291886834436614, -1.6200558406679872], [29.254834832483343, -2.2151099585089113], [29.117478875451553, -2.2922111954883846], [29.024926385216787, -2.8392579077301576], [29.276383904749053, -3.293907159034063], [29.339997592900346, -4.4999834122940925]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[41.58513, -1.6832500000000001], [40.993, -0.85829], [40.98105, 2.7845199999999997], [41.85508309264397, 3.918911920483727], [42.128609999999995, 4.23413], [42.76967, 4.25259], [43.66086999999999, 4.957550000000083], [44.96360000000001, 5.00162], [47.78942, 8.003], [48.48673587422695, 8.837626247589995], [48.93812951029645, 9.451748968946617], [48.93823286316103, 9.973500067581512], [48.938491245322496, 10.982327378783467], [48.94200524271835, 11.394266058798138], [48.94820475850974, 11.410617281697963], [48.94820475850985, 11.41061728169797], [49.26776, 11.43033], [49.72862, 11.5789], [50.25878000000001, 11.67957], [50.73202, 12.021900000000002], [51.1112, 12.024640000000002], [51.13387, 11.74815], [51.04153, 11.16651], [51.04531, 10.6409], [50.834179999999996, 10.279720000000001], [50.55239, 9.19874], [50.07092, 8.08173], [49.45270000000001, 6.80466], [48.594550000000005, 5.339110000000001], [47.740790000000004, 4.2194], [46.56476, 2.85529], [45.563990000000004, 2.04576], [44.068149999999996, 1.0528300000000002], [43.13597, 0.2922], [42.04157000000001, -0.9191600000000001], [41.81095, -1.4464700000000001], [41.58513, -1.6832500000000001]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[39.20222, -4.67677], [37.7669, -3.6771200000000004], [37.69868999999994, -3.0969899999999484], [34.07261999999997, -1.0598199999999451], [33.90371119710453, -0.9500000000000001], [33.893568969666944, 0.1098135378618963], [34.18, 0.515], [34.6721, 1.1769399999999999], [35.03599, 1.90584], [34.59607, 3.0537400000001185], [34.47913, 3.5556000000000836], [34.005, 4.249884947362048], [34.62019626785388, 4.8471227420819885], [35.29800711823298, 5.506], [35.817447662353516, 5.338232082790797], [35.817447662353516, 4.7769656634618896], [36.159078632855646, 4.447864127672769], [36.85509323800812, 4.447864127672769], [38.120915, 3.598605], [38.43697, 3.58851], [38.67114, 3.6160700000000006], [38.89251, 3.5007400000000004], [39.55938425876585, 3.42206], [39.85494, 3.83879], [40.76848, 4.257020000000001], [41.1718, 3.9190899999999997], [41.85508309264397, 3.918911920483727], [40.98105, 2.7845199999999997], [40.993, -0.85829], [41.58513, -1.6832500000000001], [40.88477, -2.08255], [40.63785000000001, -2.49979], [40.26304000000001, -2.57309], [40.12119, -3.27768], [39.80006, -3.68116], [39.604890000000005, -4.3465300000000004], [39.20222, -4.67677]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[24.567369012152085, 8.229187933785468], [23.805813429466752, 8.666318874542526], [23.459012892355986, 8.954285793488893], [23.394779087017184, 9.265067857292223], [23.55724979014283, 9.681218166538684], [23.554304233502194, 10.089255275915308], [22.97754357269261, 10.71446259199854], [22.864165480244225, 11.142395127807546], [22.876219999999932, 11.384610000000123], [22.50869, 11.679360000000031], [22.497619999999984, 12.260240000000067], [22.288010000000043, 12.646049999999946], [21.93680999999998, 12.588180000000136], [22.037589999999966, 12.95545999999996], [22.296580000000006, 13.372319999999945], [22.18329, 13.78648000000004], [22.512020000000007, 14.093179999999961], [22.30350999999996, 14.326820000000055], [22.56795000000011, 14.944290000000137], [23.024590000000103, 15.680720000000065], [23.886890000000108, 15.610839999999996], [23.83766000000014, 19.580470000000105], [23.850000000000136, 20.000000000000057], [25.000000000000114, 20.003040000000055], [25.0, 22.0], [29.019999999999982, 22.0], [32.89999999999998, 22.0], [36.86622999999997, 22.0], [37.1887200000001, 21.018850000000043], [36.969409999999925, 20.83744000000013], [37.11470000000014, 19.807960000000094], [37.4817900000001, 18.61409000000009], [37.862760000000094, 18.36785999999995], [38.410089959473225, 17.998307399970315], [37.90400000000011, 17.427540000000022], [37.167470000000094, 17.263140000000135], [36.852530000000115, 16.956549999999993], [36.75389000000007, 16.291860000000042], [36.32321999999999, 14.822490000000016], [36.42951000000005, 14.422110000000032], [36.27022000000005, 13.563330000000121], [35.86363, 12.578280000000063], [35.26049000000006, 12.08286000000004], [34.83163000000013, 11.318960000000118], [34.73115000000013, 10.910170000000107], [34.25745000000006, 10.630089999999996], [33.961620000000096, 9.583580000000097], [33.97498000000007, 8.68455999999992], [33.963392794971185, 9.464285229420625], [33.82496348090751, 9.484060845715362], [33.84213085302815, 9.981914637215993], [33.72195924818311, 10.325262079630193], [33.206938084561784, 10.720111638406593], [33.086766479716744, 11.441141267476496], [33.206938084561784, 12.179338268667095], [32.743419037302544, 12.248007757149992], [32.67474954881965, 12.02483191958072], [32.073891524594785, 11.973329803218519], [32.31423473428475, 11.68148447716652], [32.400071594888345, 11.080626452941488], [31.850715687025513, 10.531270545078826], [31.35286189552488, 9.810240916008695], [30.837840731903384, 9.70723668328452], [29.996639497988554, 10.290927335388687], [29.61895731133285, 10.084918869940225], [29.515953078608618, 9.793073543888056], [29.000931914987177, 9.60423245056029], [28.966597170745786, 9.398223985111656], [27.970889587744352, 9.398223985111656], [27.833550610778786, 9.60423245056029], [27.112520981708883, 9.638567194801624], [26.752006167173818, 9.466893473594496], [26.477328213242515, 9.552730334198088], [25.962307049621018, 10.136420986302426], [25.790633328413946, 10.411098940233728], [25.069603699343986, 10.273759963267992], [24.794925745412684, 9.810240916008695], [24.53741516360202, 8.91753756573172], [24.19406772118765, 8.728696472403897], [23.886979580860668, 8.619729712933065], [24.567369012152085, 8.229187933785468]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[23.83766000000014, 19.580470000000105], [23.886890000000108, 15.610839999999996], [23.024590000000103, 15.680720000000065], [22.56795000000011, 14.944290000000137], [22.30350999999996, 14.326820000000055], [22.512020000000007, 14.093179999999961], [22.18329, 13.78648000000004], [22.296580000000006, 13.372319999999945], [22.037589999999966, 12.95545999999996], [21.93680999999998, 12.588180000000136], [22.288010000000043, 12.646049999999946], [22.497619999999984, 12.260240000000067], [22.50869, 11.679360000000031], [22.876219999999932, 11.384610000000123], [22.864165480244225, 11.142395127807546], [22.23112918466876, 10.97188873946061], [21.723821648859456, 10.567055568885976], [21.000868361096167, 9.475985215691509], [20.05968549976427, 9.012706000194854], [19.09400800952602, 9.07484691002584], [18.812009718509273, 8.982914536978598], [18.911021762780507, 8.630894680206353], [18.38955488452322, 8.281303615751824], [17.964929640380888, 7.890914008002994], [16.705988396886255, 7.5083275415299795], [16.456184523187346, 7.734773667832968], [16.290561557691888, 7.754307359239419], [16.106231723706742, 7.497087917506462], [15.279460483469109, 7.421924546737969], [15.436091749745742, 7.692812404811889], [15.120865512765306, 8.382150173369439], [14.97999555833769, 8.796104234243472], [14.54446658698177, 8.965861314322268], [13.954218377344006, 9.549494940626687], [14.171466098699028, 10.021378282099931], [14.62720055508106, 9.920919297724538], [14.909353875394716, 9.992129421422732], [15.467872755605242, 9.982336737503545], [14.92356489427496, 10.891325181517473], [14.9601518083376, 11.555574042197224], [14.89336000000003, 12.219049999999982], [14.495787387762846, 12.85939626713733], [14.595781284247607, 13.33042694747786], [13.95447675950561, 13.353448798063766], [13.956698846094127, 13.996691189016929], [13.540393507550789, 14.367133693901224], [13.972170000000006, 15.684370000000058], [15.247731154041844, 16.627305813050782], [15.30044111497972, 17.927949937405003], [15.685740594147774, 19.957180080642388], [15.903246697664315, 20.387618923417506], [15.487148064850146, 20.730414537025638], [15.47106000000008, 21.04845000000006], [15.096887648181848, 21.30851878507491], [14.851300000000037, 22.862950000000126], [15.860850000000084, 23.409719999999993], [19.849260000000072, 21.49509000000006], [23.83766000000014, 19.580470000000105]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[16.344976840895242, -28.5767050106977], [16.824017368240902, -28.08216155366447], [17.218928663815404, -28.35594329194681], [17.387497185951503, -28.78351409272978], [17.83615197110953, -28.85637786226132], [18.464899122804752, -29.04546192801728], [19.002127312911085, -28.972443129188868], [19.894734327888614, -28.461104831660776], [19.895767856534434, -24.76779021576059], [20.16572553882719, -24.91796192800077], [20.75860924651184, -25.86813648855145], [20.66647016773544, -26.477453301704923], [20.88960900237174, -26.828542982695915], [21.605896030369394, -26.726533705351756], [22.105968865657868, -26.280256036079138], [22.57953169118059, -25.979447523708146], [22.8242712745149, -25.50045867279477], [23.312096795350186, -25.26868987396572], [23.73356977712271, -25.390129489851617], [24.211266717228796, -25.670215752873574], [25.025170525825786, -25.7196700985769], [25.66466637543772, -25.486816094669713], [25.76584882986521, -25.17484547292368], [25.94165205252216, -24.69637338633322], [26.4857532081233, -24.616326592713104], [26.786406691197413, -24.240690606383485], [27.119409620886245, -23.574323011979775], [28.01723595552525, -22.82775359465908], [29.43218834810904, -22.091312758067588], [29.839036899542972, -22.102216485281176], [30.322883335091774, -22.271611830333935], [30.65986535006709, -22.151567478119915], [31.19140913262129, -22.2515096981724], [31.670397983534656, -23.658969008073864], [31.930588820124253, -24.36941659922254], [31.75240848158188, -25.484283949487413], [31.83777794772806, -25.84333180105135], [31.333157586397903, -25.66019052500895], [31.04407962415715, -25.731452325139443], [30.949666782359913, -26.02264902110415], [30.67660851412964, -26.398078301704608], [30.68596194837448, -26.743845310169533], [31.28277306491333, -27.285879408478998], [31.86806033705108, -27.177927341421277], [32.07166548028107, -26.73382008230491], [32.830120477028885, -26.742191664336197], [32.580264926897684, -27.470157566031816], [32.46213260267845, -28.301011244420557], [32.20338870619304, -28.75240488049007], [31.521001417778876, -29.257386976846256], [31.325561150851, -29.401977634398914], [30.901762729625347, -29.909956963828037], [30.62281334811382, -30.42377573010613], [30.05571618014278, -31.140269463832958], [28.92555260591954, -32.1720411109725], [28.2197558936771, -32.771952813448856], [27.464608188595975, -33.2269637997788], [26.419452345492825, -33.61495045342619], [25.90966434093349, -33.6670402971764], [25.780628289500697, -33.94464609144834], [25.172861769315972, -33.796851495093584], [24.677853224392123, -33.98717579522455], [23.594043409934642, -33.794474379208154], [22.988188917744736, -33.91643075941698], [22.574157342222236, -33.86408253350531], [21.542799106541025, -34.258838799782936], [20.689052768647002, -34.417175388325234], [20.071261020597632, -34.79513681410799], [19.61640506356457, -34.81916635512371], [19.193278435958717, -34.46259897230979], [18.85531456876987, -34.444305515278465], [18.42464318204938, -33.99787281670897], [18.377410922934615, -34.13652068454807], [18.24449913907992, -33.86775156019803], [18.250080193767445, -33.28143075941444], [17.92519046394844, -32.61129078545343], [18.247909783611192, -32.42913136162457], [18.22176150887148, -31.66163298922567], [17.56691775886887, -30.725721123987547], [17.064416131262703, -29.878641045859162], [17.062917514726223, -29.875953871379984], [16.344976840895242, -28.5767050106977]], [[28.978262566857243, -28.95559661226171], [28.541700066855498, -28.64750172293757], [28.074338413207784, -28.851468601193588], [27.532511020627478, -29.24271087007536], [26.999261915807637, -29.875953871379984], [27.749397006956485, -30.645105889612225], [28.107204624145425, -30.54573211031495], [28.29106937023991, -30.2262167294543], [28.84839969250774, -30.070050551068256], [29.018415154748027, -29.74376555757737], [29.32516645683259, -29.257386976846256], [28.978262566857243, -28.95559661226171]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[28.978262566857243, -28.95559661226171], [29.32516645683259, -29.257386976846256], [29.018415154748027, -29.74376555757737], [28.84839969250774, -30.070050551068256], [28.29106937023991, -30.2262167294543], [28.107204624145425, -30.54573211031495], [27.749397006956485, -30.645105889612225], [26.999261915807637, -29.875953871379984], [27.532511020627478, -29.24271087007536], [28.074338413207784, -28.851468601193588], [28.541700066855498, -28.64750172293757], [28.978262566857243, -28.95559661226171]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[31.19140913262129, -22.2515096981724], [30.65986535006709, -22.151567478119915], [30.322883335091774, -22.271611830333935], [29.839036899542972, -22.102216485281176], [29.43218834810904, -22.091312758067588], [28.794656202924216, -21.63945403410745], [28.021370070108617, -21.485975030200585], [27.72722781750326, -20.851801853114715], [27.724747348753255, -20.49905852629039], [27.296504754350508, -20.391519870691], [26.164790887158485, -19.29308562589494], [25.85039147309473, -18.714412937090536], [25.649163445750162, -18.53602589281899], [25.264225701608012, -17.736539808831417], [26.381935255648926, -17.8460421688579], [26.70677330903564, -17.961228936436484], [27.044427117630732, -17.938026218337434], [27.59824344250276, -17.290830580314008], [28.467906121542683, -16.468400160388846], [28.8258687680285, -16.389748630440614], [28.947463413211267, -16.04305144619444], [29.516834344203147, -15.644677829656388], [30.27425581230511, -15.507786960515213], [30.338954705534544, -15.880839125230246], [31.17306399915768, -15.860943698797874], [31.636498243951195, -16.071990248277885], [31.8520406430406, -16.319417006091378], [32.32823896661023, -16.392074069893752], [32.847638787575846, -16.713398125884616], [32.84986087416439, -17.97905730557718], [32.65488569512715, -18.672089939043495], [32.61199425632489, -19.419382826416275], [32.772707960752626, -19.715592136313298], [32.65974327976258, -20.304290052982317], [32.50869306817344, -20.395292250248307], [32.244988234188014, -21.116488539313693], [31.19140913262129, -22.2515096981724]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[29.43218834810904, -22.091312758067588], [28.01723595552525, -22.82775359465908], [27.119409620886245, -23.574323011979775], [26.786406691197413, -24.240690606383485], [26.4857532081233, -24.616326592713104], [25.94165205252216, -24.69637338633322], [25.76584882986521, -25.17484547292368], [25.66466637543772, -25.486816094669713], [25.025170525825786, -25.7196700985769], [24.211266717228796, -25.670215752873574], [23.73356977712271, -25.390129489851617], [23.312096795350186, -25.26868987396572], [22.8242712745149, -25.50045867279477], [22.57953169118059, -25.979447523708146], [22.105968865657868, -26.280256036079138], [21.605896030369394, -26.726533705351756], [20.88960900237174, -26.828542982695915], [20.66647016773544, -26.477453301704923], [20.75860924651184, -25.86813648855145], [20.16572553882719, -24.91796192800077], [19.895767856534434, -24.76779021576059], [19.89545779794068, -21.84915699634787], [20.88113406747587, -21.814327080983148], [20.910641310314535, -18.252218926672022], [21.655040317478978, -18.219146010005225], [23.1968583513393, -17.869038181227786], [23.579005568137717, -18.28126108162006], [24.217364536239213, -17.88934701911849], [24.520705193792537, -17.887124932529936], [25.08444339366457, -17.661815687737374], [25.264225701608012, -17.736539808831417], [25.649163445750162, -18.53602589281899], [25.85039147309473, -18.714412937090536], [26.164790887158485, -19.29308562589494], [27.296504754350508, -20.391519870691], [27.724747348753255, -20.49905852629039], [27.72722781750326, -20.851801853114715], [28.021370070108617, -21.485975030200585], [28.794656202924216, -21.63945403410745], [29.43218834810904, -22.091312758067588]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[19.895767856534434, -24.76779021576059], [19.894734327888614, -28.461104831660776], [19.002127312911085, -28.972443129188868], [18.464899122804752, -29.04546192801728], [17.83615197110953, -28.85637786226132], [17.387497185951503, -28.78351409272978], [17.218928663815404, -28.35594329194681], [16.824017368240902, -28.08216155366447], [16.344976840895242, -28.5767050106977], [15.601818068105816, -27.821247247022804], [15.21047244635946, -27.090955905874047], [14.989710727608553, -26.117371921495156], [14.743214145576331, -25.39292001719538], [14.408144158595833, -23.853014011329847], [14.385716586981149, -22.65665292734069], [14.257714064194175, -22.111208184499958], [13.86864220546866, -21.699036960539978], [13.35249799973744, -20.872834161057504], [12.826845330464494, -19.673165785401665], [12.608564080463621, -19.0453488094877], [11.794918654028066, -18.069129327061916], [11.734198846085121, -17.301889336824473], [12.215461460019355, -17.111668389558083], [12.814081251688407, -16.94134286872407], [13.462362094789967, -16.971211846588773], [14.05850141770901, -17.423380629142663], [14.209706658595024, -17.35310068122572], [18.263309360434164, -17.309950860262006], [18.956186964603603, -17.789094740472258], [21.377176141045567, -17.930636488519696], [23.215048455506064, -17.523116143465984], [24.033861525170778, -17.295843194246324], [24.682349074001507, -17.353410739819473], [25.07695031098226, -17.57882333747662], [25.08444339366457, -17.661815687737374], [24.520705193792537, -17.887124932529936], [24.217364536239213, -17.88934701911849], [23.579005568137717, -18.28126108162006], [23.1968583513393, -17.869038181227786], [21.655040317478978, -18.219146010005225], [20.910641310314535, -18.252218926672022], [20.88113406747587, -21.814327080983148], [19.89545779794068, -21.84915699634787], [19.895767856534434, -24.76779021576059]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[-16.71372880702347, 13.594958604379855], [-17.126106736712615, 14.373515733289224], [-17.62504269049066, 14.729540513564073], [-17.18517289882223, 14.919477240452862], [-16.700706346085923, 15.621527411354108], [-16.463098110407884, 16.13503611903846], [-16.12069007004193, 16.455662543193384], [-15.623666144258692, 16.369337063049812], [-15.135737270558819, 16.587282416240782], [-14.577347581428981, 16.59826365810281], [-14.099521450242179, 16.304302273010492], [-13.435737677453062, 16.03938304286619], [-12.830658331747516, 15.303691514542948], [-12.170750291380301, 14.616834214735505], [-12.12488745772126, 13.994727484589788], [-11.927716030311615, 13.422075100147396], [-11.55339779300543, 13.141213690641067], [-11.467899135778524, 12.754518947800975], [-11.51394283695059, 12.442987575729418], [-11.658300950557932, 12.386582749882836], [-12.203564825885634, 12.465647691289405], [-12.27859900557344, 12.354440008997287], [-12.499050665730564, 12.332089952031057], [-13.217818162478238, 12.575873521367967], [-13.700476040084325, 12.586182969610194], [-15.54847693527401, 12.628170070847347], [-15.816574266004254, 12.515567124883347], [-16.147716844130585, 12.547761542201187], [-16.677451951554573, 12.384851589401052], [-16.841524624081273, 13.15139394780256], [-15.931295945692211, 13.130284125211332], [-15.691000535534995, 13.270353094938457], [-15.511812506562933, 13.278569647672867], [-15.141163295949468, 13.509511623585238], [-14.712197231494628, 13.298206691943777], [-14.277701788784555, 13.280585028532244], [-13.844963344772408, 13.505041612192002], [-14.046992356817482, 13.79406789800045], [-14.376713833055788, 13.625680243377374], [-14.687030808968487, 13.630356960499784], [-15.08173539881382, 13.876491807505985], [-15.39877031092446, 13.86036876063092], [-15.624596320039942, 13.62358734786956], [-16.71372880702347, 13.594958604379855]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[-11.51394283695059, 12.442987575729418], [-11.467899135778524, 12.754518947800975], [-11.55339779300543, 13.141213690641067], [-11.927716030311615, 13.422075100147396], [-12.12488745772126, 13.994727484589788], [-12.170750291380301, 14.616834214735505], [-11.834207526079467, 14.79909699142894], [-11.666078253617854, 15.388208319556298], [-11.349095017939504, 15.411256008358478], [-10.650791388379417, 15.132745876521426], [-10.086846482778213, 15.330485744686271], [-9.700255092802706, 15.264107367407362], [-9.55023840985939, 15.486496893775438], [-5.537744309908447, 15.501689764869257], [-5.315277268891933, 16.20185374599184], [-5.488522508150439, 16.325102037007966], [-5.9711287093242476, 20.64083344164763], [-6.453786586930335, 24.956590684503425], [-4.923337368174231, 24.974574082941], [-1.5500548974576134, 22.792665920497384], [1.8232275732590324, 20.610809434486043], [2.06099083823392, 20.142233384679486], [2.683588494486429, 19.856230170160117], [3.1466610042539003, 19.693578599521445], [3.158133172222705, 19.057364203360038], [4.267419467800039, 19.155265204337], [4.2702099951438015, 16.852227484601215], [3.7234216650634835, 16.184283759012615], [3.6382589046464773, 15.568119818580456], [2.749992709981484, 15.409524847876696], [1.3855281917468576, 15.323561102759172], [1.0157833186984817, 14.96818227788799], [0.3748922054146817, 14.92890818934613], [-0.2662572900305804, 14.924308986872148], [-0.5158544580003479, 15.116157741755728], [-1.0663634912056636, 14.973815009007765], [-2.001035122068771, 14.559008287000893], [-2.1918245100903846, 14.246417548067356], [-2.9676944645205765, 13.79815033615151], [-3.1037068343127596, 13.541266791228594], [-3.522802700199861, 13.337661647998615], [-4.006390753587226, 13.472485459848116], [-4.28040503581488, 13.228443508349741], [-4.427166103523803, 12.542645575404295], [-5.220941941743121, 11.713858954307227], [-5.1978425765086484, 11.37514577885014], [-5.470564947929006, 10.951269842976048], [-5.404341599946974, 10.370736802609146], [-5.816926235365287, 10.222554633012194], [-6.050452032892267, 10.096360785355444], [-6.205222947606431, 10.524060777219134], [-6.493965013037268, 10.411302801958271], [-6.666460944027548, 10.430810655148449], [-6.8505065576350574, 10.138993841996239], [-7.622759161804809, 10.147236232946796], [-7.899589809592372, 10.297382106970828], [-8.029943610048619, 10.206534939001713], [-8.33537716310974, 10.494811916541934], [-8.282357143578281, 10.792597357623846], [-8.407310756860028, 10.909256903522762], [-8.620321010767128, 10.810890814655183], [-8.581305304386774, 11.136245632364805], [-8.376304897484914, 11.393645941610629], [-8.786099005559464, 11.812560939984706], [-8.90526485842453, 12.088358059126437], [-9.127473517279583, 12.308060411015333], [-9.327616339546012, 12.334286200403454], [-9.567911749703214, 12.194243068892476], [-9.890992804392013, 12.060478623904972], [-10.165213792348837, 11.844083563682744], [-10.593223842806282, 11.92397532800598], [-10.870829637078215, 12.17788747807211], [-11.03655595543826, 12.211244615116515], [-11.297573614944511, 12.077971096235771], [-11.456168585648271, 12.076834214725338], [-11.51394283695059, 12.442987575729418]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[-17.06342322434257, 20.999752102130827], [-16.845193650773993, 21.33332347257488], [-12.929101935263532, 21.327070624267563], [-13.118754441774712, 22.771220201096256], [-12.874221564169575, 23.284832261645178], [-11.937224493853321, 23.374594224536168], [-11.96941891117116, 25.933352769468268], [-8.6872936670174, 25.881056219988906], [-8.684399786809053, 27.395744126896005], [-4.923337368174231, 24.974574082941], [-6.453786586930335, 24.956590684503425], [-5.9711287093242476, 20.64083344164763], [-5.488522508150439, 16.325102037007966], [-5.315277268891933, 16.20185374599184], [-5.537744309908447, 15.501689764869257], [-9.55023840985939, 15.486496893775438], [-9.700255092802706, 15.264107367407362], [-10.086846482778213, 15.330485744686271], [-10.650791388379417, 15.132745876521426], [-11.349095017939504, 15.411256008358478], [-11.666078253617854, 15.388208319556298], [-11.834207526079467, 14.79909699142894], [-12.170750291380301, 14.616834214735505], [-12.830658331747516, 15.303691514542948], [-13.435737677453062, 16.03938304286619], [-14.099521450242179, 16.304302273010492], [-14.577347581428981, 16.59826365810281], [-15.135737270558819, 16.587282416240782], [-15.623666144258692, 16.369337063049812], [-16.12069007004193, 16.455662543193384], [-16.463098110407884, 16.13503611903846], [-16.549707810929064, 16.673892116761962], [-16.270551723688357, 17.166962795474873], [-16.14634741867485, 18.108481553616656], [-16.256883307347167, 19.096715806550307], [-16.37765112961327, 19.593817246981985], [-16.277838100641517, 20.0925206568147], [-16.536323614965468, 20.567866319251493], [-17.06342322434257, 20.999752102130827]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[2.6917016943562544, 6.258817246928629], [1.8652405127123188, 6.142157701029731], [1.618950636409238, 6.832038072126238], [1.664477573258381, 9.12859039960938], [1.46304284018467, 9.334624335157088], [1.425060662450136, 9.825395412633], [1.0777950374487375, 10.175606594275024], [0.7723356461714843, 10.470808213742359], [0.8995630224740694, 10.99733938236426], [1.2434696793764886, 11.110510769083461], [1.4471781754710662, 11.547719224488858], [1.9359855485198807, 11.641150214072553], [2.1544735042499212, 11.940150051313339], [2.49016360841793, 12.233052069543675], [2.8486430192265857, 12.23563589115821], [3.611180454125559, 11.660167141155968], [3.572216424177469, 11.32793935795152], [3.7971122575117136, 10.734745591673105], [3.600070021182802, 10.332186184119408], [3.7054382666259187, 10.063210354040208], [3.2203515967021015, 9.444152533399702], [2.912308383810256, 9.137607937044322], [2.723792758809509, 8.50684540448971], [2.7490625342002204, 7.870734361192888], [2.6917016943562544, 6.258817246928629]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[14.851300000000037, 22.862950000000126], [15.096887648181848, 21.30851878507491], [15.47106000000008, 21.04845000000006], [15.487148064850146, 20.730414537025638], [15.903246697664315, 20.387618923417506], [15.685740594147774, 19.957180080642388], [15.30044111497972, 17.927949937405003], [15.247731154041844, 16.627305813050782], [13.972170000000006, 15.684370000000058], [13.540393507550789, 14.367133693901224], [13.956698846094127, 13.996691189016929], [13.95447675950561, 13.353448798063766], [14.595781284247607, 13.33042694747786], [14.495787387762846, 12.85939626713733], [14.213530714584635, 12.802035427293347], [14.181336297266794, 12.483656927943116], [13.995352817448293, 12.461565253138303], [13.318701613018561, 13.556356309457826], [13.083987257548813, 13.596147162322495], [12.302071160540523, 13.037189032437524], [11.527803175511394, 13.328980007373588], [10.989593133191534, 13.387322699431195], [10.701031935273706, 13.246917832894084], [10.114814487354693, 13.27725189864941], [9.524928012742947, 12.851102199754479], [9.014933302454438, 12.826659247280418], [7.804671258178786, 13.343526923063747], [7.330746697630019, 13.0980380314612], [6.820441928747754, 13.115091254117518], [6.445426059605637, 13.492768459522678], [5.443058302440136, 13.865923977102227], [4.368343540066007, 13.747481594289411], [4.107945997747322, 13.531215725147831], [3.9672827490488487, 12.956108710171575], [3.6806335791258107, 12.552903347214226], [3.611180454125559, 11.660167141155968], [2.8486430192265857, 12.23563589115821], [2.49016360841793, 12.233052069543675], [2.1544735042499212, 11.940150051313339], [2.177107781593776, 12.625017808477535], [1.0241032242974768, 12.851825669806574], [0.9930456884900708, 13.335749620003824], [0.429927605805517, 13.988733018443924], [0.29564639649510127, 14.444234930880654], [0.3748922054146817, 14.92890818934613], [1.0157833186984817, 14.96818227788799], [1.3855281917468576, 15.323561102759172], [2.749992709981484, 15.409524847876696], [3.6382589046464773, 15.568119818580456], [3.7234216650634835, 16.184283759012615], [4.2702099951438015, 16.852227484601215], [4.267419467800039, 19.155265204337], [5.677565952180686, 19.601206976799716], [8.572893100629784, 21.565660712159143], [11.999505649471613, 23.47166840259645], [13.581424594790462, 23.04050608976928], [14.143870883855243, 22.491288967371133], [14.851300000000037, 22.862950000000126]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[2.6917016943562544, 6.258817246928629], [2.7490625342002204, 7.870734361192888], [2.723792758809509, 8.50684540448971], [2.912308383810256, 9.137607937044322], [3.2203515967021015, 9.444152533399702], [3.7054382666259187, 10.063210354040208], [3.600070021182802, 10.332186184119408], [3.7971122575117136, 10.734745591673105], [3.572216424177469, 11.32793935795152], [3.611180454125559, 11.660167141155968], [3.6806335791258107, 12.552903347214226], [3.9672827490488487, 12.956108710171575], [4.107945997747322, 13.531215725147831], [4.368343540066007, 13.747481594289411], [5.443058302440136, 13.865923977102227], [6.445426059605637, 13.492768459522678], [6.820441928747754, 13.115091254117518], [7.330746697630019, 13.0980380314612], [7.804671258178786, 13.343526923063747], [9.014933302454438, 12.826659247280418], [9.524928012742947, 12.851102199754479], [10.114814487354693, 13.27725189864941], [10.701031935273706, 13.246917832894084], [10.989593133191534, 13.387322699431195], [11.527803175511394, 13.328980007373588], [12.302071160540523, 13.037189032437524], [13.083987257548813, 13.596147162322495], [13.318701613018561, 13.556356309457826], [13.995352817448293, 12.461565253138303], [14.181336297266794, 12.483656927943116], [14.577177768622533, 12.085360826053503], [14.468192172918975, 11.904751695193411], [14.415378859116684, 11.572368882692075], [13.572949659894562, 10.798565985553566], [13.308676385153918, 10.160362046748928], [13.167599724997103, 9.640626328973411], [12.955467970438974, 9.417771714714704], [12.753671502339216, 8.717762762888995], [12.218872104550599, 8.305824082874324], [12.063946160539558, 7.799808457872302], [11.839308709366803, 7.397042344589437], [11.74577436691851, 6.981382961449754], [11.058787876030351, 6.6444267846905944], [10.497375115611419, 7.0553577742755635], [10.118276808318257, 7.03876963950988], [9.522705926154401, 6.453482367372117], [9.233162876023044, 6.444490668153335], [8.757532993208628, 5.479665839047911], [8.500287713259695, 4.7719829370268485], [7.462108188515941, 4.412108262546241], [7.0825964697644395, 4.4646890324032285], [6.6980721370806, 4.240594183769517], [5.898172641634687, 4.262453314628985], [5.3628048030908815, 4.887970689305959], [5.033574252959369, 5.611802476418234], [4.325607130560684, 6.2706511499234665], [3.574180128604553, 6.258300482605719], [2.6917016943562544, 6.258817246928629]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[14.495787387762846, 12.85939626713733], [14.89336000000003, 12.219049999999982], [14.9601518083376, 11.555574042197224], [14.92356489427496, 10.891325181517473], [15.467872755605242, 9.982336737503545], [14.909353875394716, 9.992129421422732], [14.62720055508106, 9.920919297724538], [14.171466098699028, 10.021378282099931], [13.954218377344006, 9.549494940626687], [14.54446658698177, 8.965861314322268], [14.97999555833769, 8.796104234243472], [15.120865512765306, 8.382150173369439], [15.436091749745742, 7.692812404811889], [15.279460483469109, 7.421924546737969], [14.776545444404576, 6.408498033062045], [14.536560092841114, 6.2269587264206905], [14.459407179429348, 5.4517605656103], [14.558935988023507, 5.03059764243153], [14.47837243008047, 4.732605495620447], [14.950953403389661, 4.210389309094921], [15.036219516671252, 3.8513672957471243], [15.405395948964383, 3.33530060466434], [15.862732374747482, 3.0135372989989833], [15.907380812247652, 2.557389431158612], [16.012852410555354, 2.267639675298085], [15.940918816805066, 1.7276726342802957], [15.146341993885244, 1.9640147973671844], [14.33781253424658, 2.2278746606494906], [13.075822381246752, 2.2670970727590145], [12.951333855855609, 2.32161570882694], [12.359380323952221, 2.19281220133945], [11.75166548019979, 2.3267575138399934], [11.276449008843713, 2.261050930180872], [9.649158155972628, 2.2838660750377358], [9.795195753629457, 3.073404445809117], [9.404366896206, 3.734526882335203], [8.948115675501072, 3.9041289331171356], [8.744923943729418, 4.35221527751996], [8.48881554529089, 4.495617377129918], [8.500287713259695, 4.7719829370268485], [8.757532993208628, 5.479665839047911], [9.233162876023044, 6.444490668153335], [9.522705926154401, 6.453482367372117], [10.118276808318257, 7.03876963950988], [10.497375115611419, 7.0553577742755635], [11.058787876030351, 6.6444267846905944], [11.74577436691851, 6.981382961449754], [11.839308709366803, 7.397042344589437], [12.063946160539558, 7.799808457872302], [12.218872104550599, 8.305824082874324], [12.753671502339216, 8.717762762888995], [12.955467970438974, 9.417771714714704], [13.167599724997103, 9.640626328973411], [13.308676385153918, 10.160362046748928], [13.572949659894562, 10.798565985553566], [14.415378859116684, 11.572368882692075], [14.468192172918975, 11.904751695193411], [14.577177768622533, 12.085360826053503], [14.181336297266794, 12.483656927943116], [14.213530714584635, 12.802035427293347], [14.495787387762846, 12.85939626713733]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[0.8995630224740694, 10.99733938236426], [0.7723356461714843, 10.470808213742359], [1.0777950374487375, 10.175606594275024], [1.425060662450136, 9.825395412633], [1.46304284018467, 9.334624335157088], [1.664477573258381, 9.12859039960938], [1.618950636409238, 6.832038072126238], [1.8652405127123188, 6.142157701029731], [1.0601216976049272, 5.928837388528876], [0.8369311865363329, 6.279978745952149], [0.5703841487748491, 6.914358628767189], [0.4909574723422451, 7.411744289576475], [0.7120292496868785, 8.31246450442383], [0.46119184734212126, 8.677222601756014], [0.3659005061958851, 9.465003973829482], [0.3675799902453889, 10.19121287682718], [-0.04978471515994442, 10.706917832883931], [0.023802524423700785, 11.018681748900804], [0.8995630224740694, 10.99733938236426]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[0.023802524423700785, 11.018681748900804], [-0.04978471515994442, 10.706917832883931], [0.3675799902453889, 10.19121287682718], [0.3659005061958851, 9.465003973829482], [0.46119184734212126, 8.677222601756014], [0.7120292496868785, 8.31246450442383], [0.4909574723422451, 7.411744289576475], [0.5703841487748491, 6.914358628767189], [0.8369311865363329, 6.279978745952149], [1.0601216976049272, 5.928837388528876], [-0.5076379052659377, 5.3434726017426755], [-1.0636246402941936, 5.000547797053812], [-1.9647065901675944, 4.710462144383371], [-2.856125047202397, 4.994475816259509], [-2.8107014632178395, 5.38905121502411], [-3.244370083011262, 6.250471503113502], [-2.9835849674503265, 7.379704901555513], [-2.562189500326241, 8.219627793811483], [-2.8274963037127065, 9.642460842319778], [-2.9638962467471117, 10.395334784380083], [-2.9404093082704605, 10.962690334512558], [-1.2033577132114317, 11.009819240762738], [-0.7615758935481834, 10.936929633015055], [-0.43870154458858224, 11.098340969278722], [0.023802524423700785, 11.018681748900804]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[-8.029943610048619, 10.206534939001713], [-7.899589809592372, 10.297382106970828], [-7.622759161804809, 10.147236232946796], [-6.8505065576350574, 10.138993841996239], [-6.666460944027548, 10.430810655148449], [-6.493965013037268, 10.411302801958271], [-6.205222947606431, 10.524060777219134], [-6.050452032892267, 10.096360785355444], [-5.816926235365287, 10.222554633012194], [-5.404341599946974, 10.370736802609146], [-4.954653286143099, 10.152713934769736], [-4.7798835921319665, 9.821984768101743], [-4.3302469547603835, 9.610834865757141], [-3.9804491845766847, 9.8623440617217], [-3.511898972986273, 9.90032623945622], [-2.8274963037127065, 9.642460842319778], [-2.562189500326241, 8.219627793811483], [-2.9835849674503265, 7.379704901555513], [-3.244370083011262, 6.250471503113502], [-2.8107014632178395, 5.38905121502411], [-2.856125047202397, 4.994475816259509], [-3.3110843571000714, 4.984295559098015], [-4.008819545904942, 5.179813340674315], [-4.649917364917911, 5.168263658057086], [-5.8344962223445265, 4.993700669775137], [-6.528769090185847, 4.705087795425015], [-7.5189412093304355, 4.338288479017308], [-7.7121593896697505, 4.364565944837722], [-7.635368211284031, 5.188159084489456], [-7.539715135111763, 5.313345241716519], [-7.570152553731688, 5.707352199725904], [-7.993692592795881, 6.126189683451543], [-8.311347622094019, 6.193033148621083], [-8.60288021486862, 6.4675641951716605], [-8.385451626000574, 6.911800645368743], [-8.48544552248535, 7.39520783124307], [-8.439298468448698, 7.686042792181738], [-8.280703497744938, 7.687179673692157], [-8.221792364932199, 8.123328762235573], [-8.299048631208564, 8.316443589710303], [-8.20349890790088, 8.455453192575447], [-7.832100389019188, 8.575704250518626], [-8.07911373537435, 9.376223863152035], [-8.30961646161225, 9.789531968622441], [-8.229337124046822, 10.1290202905639], [-8.029943610048619, 10.206534939001713]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[-13.700476040084325, 12.586182969610194], [-13.217818162478238, 12.575873521367967], [-12.499050665730564, 12.332089952031057], [-12.27859900557344, 12.354440008997287], [-12.203564825885634, 12.465647691289405], [-11.658300950557932, 12.386582749882836], [-11.51394283695059, 12.442987575729418], [-11.456168585648271, 12.076834214725338], [-11.297573614944511, 12.077971096235771], [-11.03655595543826, 12.211244615116515], [-10.870829637078215, 12.17788747807211], [-10.593223842806282, 11.92397532800598], [-10.165213792348837, 11.844083563682744], [-9.890992804392013, 12.060478623904972], [-9.567911749703214, 12.194243068892476], [-9.327616339546012, 12.334286200403454], [-9.127473517279583, 12.308060411015333], [-8.90526485842453, 12.088358059126437], [-8.786099005559464, 11.812560939984706], [-8.376304897484914, 11.393645941610629], [-8.581305304386774, 11.136245632364805], [-8.620321010767128, 10.810890814655183], [-8.407310756860028, 10.909256903522762], [-8.282357143578281, 10.792597357623846], [-8.33537716310974, 10.494811916541934], [-8.029943610048619, 10.206534939001713], [-8.229337124046822, 10.1290202905639], [-8.30961646161225, 9.789531968622441], [-8.07911373537435, 9.376223863152035], [-7.832100389019188, 8.575704250518626], [-8.20349890790088, 8.455453192575447], [-8.299048631208564, 8.316443589710303], [-8.221792364932199, 8.123328762235573], [-8.280703497744938, 7.687179673692157], [-8.439298468448698, 7.686042792181738], [-8.722123582382125, 7.71167430259851], [-8.926064622422004, 7.309037380396376], [-9.208786383490846, 7.313920803247953], [-9.40334815106975, 7.526905218938907], [-9.337279832384581, 7.9285344507113535], [-9.755342169625834, 8.541055202666925], [-10.016566534861255, 8.428503933135232], [-10.23009355309128, 8.406205552601293], [-10.505477260774668, 8.348896389189605], [-10.494315151399633, 8.715540676300435], [-10.654770473665891, 8.977178452994195], [-10.622395188835041, 9.267910061068278], [-10.839151984083301, 9.688246161330369], [-11.11748124840733, 10.045872911006285], [-11.917277390988659, 10.046983954300558], [-12.150338100625005, 9.858571682164381], [-12.425928514037565, 9.835834051955956], [-12.59671912276221, 9.62018830000197], [-12.71195756677308, 9.342711696810767], [-13.246550258832515, 8.903048610871508], [-13.685153977909792, 9.49474376061346], [-14.074044969122282, 9.886166897008252], [-14.33007585291237, 10.015719712763968], [-14.579698859098258, 10.214467271358515], [-14.693231980843505, 10.656300767454042], [-14.839553798877944, 10.87657156009814], [-15.130311245168173, 11.040411688679526], [-14.685687221728898, 11.527823798056488], [-14.382191534878729, 11.509271958863692], [-14.121406419317779, 11.677117010947697], [-13.900799729863776, 11.678718980348748], [-13.743160773157413, 11.811269029177412], [-13.828271857142125, 12.142644151249044], [-13.718743658899513, 12.24718557377551], [-13.700476040084325, 12.586182969610194]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[-16.677451951554573, 12.384851589401052], [-16.147716844130585, 12.547761542201187], [-15.816574266004254, 12.515567124883347], [-15.54847693527401, 12.628170070847347], [-13.700476040084325, 12.586182969610194], [-13.718743658899513, 12.24718557377551], [-13.828271857142125, 12.142644151249044], [-13.743160773157413, 11.811269029177412], [-13.900799729863776, 11.678718980348748], [-14.121406419317779, 11.677117010947697], [-14.382191534878729, 11.509271958863692], [-14.685687221728898, 11.527823798056488], [-15.130311245168173, 11.040411688679526], [-15.664180467175527, 11.458474025920795], [-16.085214199273565, 11.52459402103824], [-16.314786749730203, 11.80651479740655], [-16.30894731288123, 11.95870189050612], [-16.61383826340328, 12.170911159712702], [-16.677451951554573, 12.384851589401052]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[-8.439298468448698, 7.686042792181738], [-8.48544552248535, 7.39520783124307], [-8.385451626000574, 6.911800645368743], [-8.60288021486862, 6.4675641951716605], [-8.311347622094019, 6.193033148621083], [-7.993692592795881, 6.126189683451543], [-7.570152553731688, 5.707352199725904], [-7.539715135111763, 5.313345241716519], [-7.635368211284031, 5.188159084489456], [-7.7121593896697505, 4.364565944837722], [-7.974107224957251, 4.355755113131963], [-9.004793667018674, 4.8324185245922], [-9.913420376006684, 5.593560695819207], [-10.765383876986645, 6.140710760925558], [-11.438779466182055, 6.7859168563057475], [-11.19980180504828, 7.1058456486247366], [-11.146704270868383, 7.396706447779536], [-10.69559485517648, 7.939464016141088], [-10.23009355309128, 8.406205552601293], [-10.016566534861255, 8.428503933135232], [-9.755342169625834, 8.541055202666925], [-9.337279832384581, 7.9285344507113535], [-9.40334815106975, 7.526905218938907], [-9.208786383490846, 7.313920803247953], [-8.926064622422004, 7.309037380396376], [-8.722123582382125, 7.71167430259851], [-8.439298468448698, 7.686042792181738]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[-13.246550258832515, 8.903048610871508], [-12.71195756677308, 9.342711696810767], [-12.59671912276221, 9.62018830000197], [-12.425928514037565, 9.835834051955956], [-12.150338100625005, 9.858571682164381], [-11.917277390988659, 10.046983954300558], [-11.11748124840733, 10.045872911006285], [-10.839151984083301, 9.688246161330369], [-10.622395188835041, 9.267910061068278], [-10.654770473665891, 8.977178452994195], [-10.494315151399633, 8.715540676300435], [-10.505477260774668, 8.348896389189605], [-10.23009355309128, 8.406205552601293], [-10.69559485517648, 7.939464016141088], [-11.146704270868383, 7.396706447779536], [-11.19980180504828, 7.1058456486247366], [-11.438779466182055, 6.7859168563057475], [-11.70819454593574, 6.860098374860726], [-12.428098924193819, 7.26294200279203], [-12.949049038128194, 7.798645738145738], [-13.124025437868482, 8.163946438016978], [-13.246550258832515, 8.903048610871508]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[-5.404341599946974, 10.370736802609146], [-5.470564947929006, 10.951269842976048], [-5.1978425765086484, 11.37514577885014], [-5.220941941743121, 11.713858954307227], [-4.427166103523803, 12.542645575404295], [-4.28040503581488, 13.228443508349741], [-4.006390753587226, 13.472485459848116], [-3.522802700199861, 13.337661647998615], [-3.1037068343127596, 13.541266791228594], [-2.9676944645205765, 13.79815033615151], [-2.1918245100903846, 14.246417548067356], [-2.001035122068771, 14.559008287000893], [-1.0663634912056636, 14.973815009007765], [-0.5158544580003479, 15.116157741755728], [-0.2662572900305804, 14.924308986872148], [0.3748922054146817, 14.92890818934613], [0.29564639649510127, 14.444234930880654], [0.429927605805517, 13.988733018443924], [0.9930456884900708, 13.335749620003824], [1.0241032242974768, 12.851825669806574], [2.177107781593776, 12.625017808477535], [2.1544735042499212, 11.940150051313339], [1.9359855485198807, 11.641150214072553], [1.4471781754710662, 11.547719224488858], [1.2434696793764886, 11.110510769083461], [0.8995630224740694, 10.99733938236426], [0.023802524423700785, 11.018681748900804], [-0.43870154458858224, 11.098340969278722], [-0.7615758935481834, 10.936929633015055], [-1.2033577132114317, 11.009819240762738], [-2.9404093082704605, 10.962690334512558], [-2.9638962467471117, 10.395334784380083], [-2.8274963037127065, 9.642460842319778], [-3.511898972986273, 9.90032623945622], [-3.9804491845766847, 9.8623440617217], [-4.3302469547603835, 9.610834865757141], [-4.7798835921319665, 9.821984768101743], [-4.954653286143099, 10.152713934769736], [-5.404341599946974, 10.370736802609146]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[27.37422610851749, 5.233944403500061], [27.04406538260471, 5.127852688004836], [26.402760857862543, 5.1508745385908705], [25.650455356557472, 5.256087754737123], [25.278798455514305, 5.170408229997192], [25.12883344900328, 4.92724477784779], [24.805028924262416, 4.89724660890235], [24.410531040146253, 5.10878408448913], [23.29721398285014, 4.609693101414223], [22.841479526468106, 4.710126247573484], [22.70412356943629, 4.633050848810157], [22.405123732195538, 4.029160061047321], [21.659122755630023, 4.22434194581372], [20.927591180106276, 4.322785549329737], [20.290679152108936, 4.691677761245288], [19.46778364429315, 5.03152781821278], [18.93231245288476, 4.709506130385975], [18.54298221199778, 4.201785183118318], [18.45306521980993, 3.5043858911233485], [17.809900343505262, 3.5601964379985698], [17.133042433346304, 3.728196519379452], [16.537058139724138, 3.198254706226279], [16.012852410555354, 2.267639675298085], [15.907380812247652, 2.557389431158612], [15.862732374747482, 3.0135372989989833], [15.405395948964383, 3.33530060466434], [15.036219516671252, 3.8513672957471243], [14.950953403389661, 4.210389309094921], [14.47837243008047, 4.732605495620447], [14.558935988023507, 5.03059764243153], [14.459407179429348, 5.4517605656103], [14.536560092841114, 6.2269587264206905], [14.776545444404576, 6.408498033062045], [15.279460483469109, 7.421924546737969], [16.106231723706742, 7.497087917506462], [16.290561557691888, 7.754307359239419], [16.456184523187346, 7.734773667832968], [16.705988396886255, 7.5083275415299795], [17.964929640380888, 7.890914008002994], [18.38955488452322, 8.281303615751824], [18.911021762780507, 8.630894680206353], [18.812009718509273, 8.982914536978598], [19.09400800952602, 9.07484691002584], [20.05968549976427, 9.012706000194854], [21.000868361096167, 9.475985215691509], [21.723821648859456, 10.567055568885976], [22.23112918466876, 10.97188873946061], [22.864165480244225, 11.142395127807546], [22.97754357269261, 10.71446259199854], [23.554304233502194, 10.089255275915308], [23.55724979014283, 9.681218166538684], [23.394779087017184, 9.265067857292223], [23.459012892355986, 8.954285793488893], [23.805813429466752, 8.666318874542526], [24.567369012152085, 8.229187933785468], [25.11493248871679, 7.825104071479174], [25.124130893664727, 7.500085150579437], [25.79664798351118, 6.979315904158071], [26.213418409945117, 6.546603298362072], [26.465909458123235, 5.9467174341018705], [27.21340905122517, 5.5509534773945575], [27.37422610851749, 5.233944403500061]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[18.45306521980993, 3.5043858911233485], [18.393792351971143, 2.90044342692822], [18.094275750407434, 2.365721543788055], [17.898835483479587, 1.7418319767282782], [17.774191928791566, 0.8556586775710854], [17.826540154703252, 0.28892324462610475], [17.66355268725468, -0.05808399821381727], [17.638644646889986, -0.4248316381892465], [17.523716261472856, -0.743830254726987], [16.865306837642123, -1.2258163387132868], [16.407091912510054, -1.7409270157986825], [15.972803175529151, -2.7123922664536124], [16.0062895036543, -3.535132744972529], [15.753540073314753, -3.8551648901560966], [15.170991652088444, -4.343507175314301], [14.582603794013181, -4.97023894615014], [14.209034864975223, -4.793092136253598], [14.144956088933299, -4.510008640158716], [13.600234816144678, -4.50013844159097], [13.258240187237048, -4.882957452009165], [12.995517205465177, -4.781103203961884], [12.620759718484493, -4.438023369976136], [12.318607618873926, -4.606230157086188], [11.91496300624209, -5.037986748884791], [11.093772820691925, -3.978826592630547], [11.855121697648116, -3.4268706193210505], [11.478038771214303, -2.7656189917142413], [11.820963575903193, -2.514161472181982], [12.495702752338161, -2.391688327650243], [12.575284458067642, -1.948511244315135], [13.109618767965628, -2.4287403296035137], [13.99240726080771, -2.4708049454890997], [14.299210239324566, -1.998275648612214], [14.425455763413595, -1.333406670744971], [14.316418491277744, -0.5526274552470483], [13.843320753645656, 0.038757635901149], [14.276265903386957, 1.1969298364266194], [14.026668735417218, 1.3956773950211527], [13.282631463278818, 1.3141836612968805], [13.003113641012078, 1.8308963077833198], [13.075822381246752, 2.2670970727590145], [14.33781253424658, 2.2278746606494906], [15.146341993885244, 1.9640147973671844], [15.940918816805066, 1.7276726342802957], [16.012852410555354, 2.267639675298085], [16.537058139724138, 3.198254706226279], [17.133042433346304, 3.728196519379452], [17.809900343505262, 3.5601964379985698], [18.45306521980993, 3.5043858911233485]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[11.276449008843713, 2.261050930180872], [11.75166548019979, 2.3267575138399934], [12.359380323952221, 2.19281220133945], [12.951333855855609, 2.32161570882694], [13.075822381246752, 2.2670970727590145], [13.003113641012078, 1.8308963077833198], [13.282631463278818, 1.3141836612968805], [14.026668735417218, 1.3956773950211527], [14.276265903386957, 1.1969298364266194], [13.843320753645656, 0.038757635901149], [14.316418491277744, -0.5526274552470483], [14.425455763413595, -1.333406670744971], [14.299210239324566, -1.998275648612214], [13.99240726080771, -2.4708049454890997], [13.109618767965628, -2.4287403296035137], [12.575284458067642, -1.948511244315135], [12.495702752338161, -2.391688327650243], [11.820963575903193, -2.514161472181982], [11.478038771214303, -2.7656189917142413], [11.855121697648116, -3.4268706193210505], [11.093772820691925, -3.978826592630547], [10.06613528813574, -2.9694825171056816], [9.40524539555497, -2.144313246269043], [8.79799563969317, -1.111301364754496], [8.830086704146424, -0.7790735815500369], [9.048419630579588, -0.45935149496021666], [9.29135053878369, 0.2686660831676875], [9.492888624721985, 1.010119533691494], [9.830284051155644, 1.0678937849937995], [11.285078973036462, 1.0576618514000131], [11.276449008843713, 2.261050930180872]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[9.649158155972628, 2.2838660750377358], [11.276449008843713, 2.261050930180872], [11.285078973036462, 1.0576618514000131], [9.830284051155644, 1.0678937849937995], [9.492888624721985, 1.010119533691494], [9.305613234096256, 1.1609113631191832], [9.649158155972628, 2.2838660750377358]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[30.740009731422095, -8.34000593035372], [31.15775133695005, -8.594578747317366], [31.556348097466497, -8.762048841998642], [32.19186486179194, -8.930358981973257], [32.75937544122132, -9.23059905358906], [33.2313879737753, -9.6767216935648], [33.48568769708359, -10.525558770391115], [33.315310499817286, -10.796549981329697], [33.114289178201915, -11.607198174692314], [33.306422153463075, -12.435778090060218], [32.991764357237884, -12.783870537978274], [32.68816531752313, -13.712857761289277], [33.214024692525214, -13.971860039936153], [30.17948123548183, -14.796099134991529], [30.27425581230511, -15.507786960515213], [29.516834344203147, -15.644677829656388], [28.947463413211267, -16.04305144619444], [28.8258687680285, -16.389748630440614], [28.467906121542683, -16.468400160388846], [27.59824344250276, -17.290830580314008], [27.044427117630732, -17.938026218337434], [26.70677330903564, -17.961228936436484], [26.381935255648926, -17.8460421688579], [25.264225701608012, -17.736539808831417], [25.08444339366457, -17.661815687737374], [25.07695031098226, -17.57882333747662], [24.682349074001507, -17.353410739819473], [24.033861525170778, -17.295843194246324], [23.215048455506064, -17.523116143465984], [22.56247846852426, -16.898451429921813], [21.887842644953874, -16.08031015387688], [21.933886346125917, -12.898437188369359], [24.016136508894675, -12.911046237848574], [23.930922072045377, -12.565847670138856], [24.079905226342845, -12.191296888887365], [23.904153680118185, -11.722281589406322], [24.01789350759259, -11.23729827234709], [23.912215203555718, -10.926826267137514], [24.25715538910399, -10.951992689663657], [24.31451622894795, -11.26282642989927], [24.78316979340295, -11.238693536018964], [25.418118116973204, -11.330935967659961], [25.752309604604733, -11.784965101776358], [26.553087599399618, -11.924439792532127], [27.164419793412463, -11.608748467661075], [27.388798862423783, -12.132747491100666], [28.155108676879987, -12.272480564017897], [28.523561639121027, -12.698604424696683], [28.934285922976837, -13.248958428605135], [29.69961388521949, -13.257226657771831], [29.61600141777123, -12.178894545137311], [29.34154788586909, -12.360743910372413], [28.642417433392353, -11.971568698782315], [28.372253045370428, -11.793646742401393], [28.49606977714177, -10.789883721564046], [28.67368167492893, -9.605924981324932], [28.449871046672826, -9.164918308146085], [28.734866570762502, -8.526559340044578], [29.00291222506047, -8.407031752153472], [30.346086053190817, -8.238256524288218], [30.740009731422095, -8.34000593035372]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[32.75937544122132, -9.23059905358906], [33.73972000000009, -9.417149999999992], [33.940837724096525, -9.693673841980285], [34.27999999999997, -10.160000000000025], [34.55998904799935, -11.520020033415925], [34.28000613784198, -12.280025323132506], [34.55998904799935, -13.579997653866876], [34.907151320136165, -13.565424899960568], [35.26795617039801, -13.887834161029566], [35.68684533055594, -14.611045830954332], [35.77190473810836, -15.896858819240727], [35.339062941231646, -16.10744028083011], [35.033810255683534, -16.801299737213093], [34.38129194513405, -16.183559665596043], [34.307291294092096, -15.478641452702597], [34.51766604995231, -15.013708591372612], [34.45963341648854, -14.613009535381423], [34.064825473778626, -14.35995004644812], [33.789700148256685, -14.45183074306307], [33.214024692525214, -13.971860039936153], [32.68816531752313, -13.712857761289277], [32.991764357237884, -12.783870537978274], [33.306422153463075, -12.435778090060218], [33.114289178201915, -11.607198174692314], [33.315310499817286, -10.796549981329697], [33.48568769708359, -10.525558770391115], [33.2313879737753, -9.6767216935648], [32.75937544122132, -9.23059905358906]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[34.55998904799935, -11.520020033415925], [35.31239790216904, -11.439146416879147], [36.51408165868426, -11.720938002166735], [36.775150994622805, -11.594537448780805], [37.471289999999954, -11.568759999999997], [37.827639999999974, -11.26878999999991], [38.42755659358775, -11.285202325081656], [39.52099999999996, -10.89688000000001], [40.31659000000002, -10.317099999999868], [40.316586229110854, -10.317097752817492], [40.31658857601719, -10.317096042525698], [40.47838748552303, -10.765440769089993], [40.437253045418686, -11.761710707245015], [40.56081139502857, -12.639176527561027], [40.59962039567975, -14.201975192931862], [40.775475294768995, -14.691764418194241], [40.4772506040126, -15.406294447493972], [40.08926395036522, -16.10077402106446], [39.45255862809705, -16.72089120856694], [38.53835086442152, -17.101023044505958], [37.41113284683888, -17.586368096591237], [36.28127933120936, -18.65968759529345], [35.89649661636406, -18.842260430580637], [35.198399692533144, -19.552811374593894], [34.78638349787005, -19.784011732667736], [34.70189253107284, -20.49704314543101], [35.176127150215365, -21.25436126066841], [35.37342776870574, -21.840837090748877], [35.385848253705404, -22.14], [35.562545536369086, -22.090000000000003], [35.533934767404304, -23.070787855727758], [35.37177412287238, -23.5353589820317], [35.60747033055563, -23.706563002214683], [35.45874555841962, -24.12260995859655], [35.04073489761066, -24.478350518493805], [34.21582400893547, -24.81631438568266], [33.01321007663901, -25.357573337507738], [32.574632195777866, -25.727318210556092], [32.66036339695009, -26.148584486599447], [32.91595503106569, -26.215867201443466], [32.830120477028885, -26.742191664336197], [32.07166548028107, -26.73382008230491], [31.98577924981197, -26.291779880480227], [31.83777794772806, -25.84333180105135], [31.75240848158188, -25.484283949487413], [31.930588820124253, -24.36941659922254], [31.670397983534656, -23.658969008073864], [31.19140913262129, -22.2515096981724], [32.244988234188014, -21.116488539313693], [32.50869306817344, -20.395292250248307], [32.65974327976258, -20.304290052982317], [32.772707960752626, -19.715592136313298], [32.61199425632489, -19.419382826416275], [32.65488569512715, -18.672089939043495], [32.84986087416439, -17.97905730557718], [32.847638787575846, -16.713398125884616], [32.32823896661023, -16.392074069893752], [31.8520406430406, -16.319417006091378], [31.636498243951195, -16.071990248277885], [31.17306399915768, -15.860943698797874], [30.338954705534544, -15.880839125230246], [30.27425581230511, -15.507786960515213], [30.17948123548183, -14.796099134991529], [33.214024692525214, -13.971860039936153], [33.789700148256685, -14.45183074306307], [34.064825473778626, -14.35995004644812], [34.45963341648854, -14.613009535381423], [34.51766604995231, -15.013708591372612], [34.307291294092096, -15.478641452702597], [34.38129194513405, -16.183559665596043], [35.033810255683534, -16.801299737213093], [35.339062941231646, -16.10744028083011], [35.77190473810836, -15.896858819240727], [35.68684533055594, -14.611045830954332], [35.26795617039801, -13.887834161029566], [34.907151320136165, -13.565424899960568], [34.55998904799935, -13.579997653866876], [34.28000613784198, -12.280025323132506], [34.55998904799935, -11.520020033415925]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[32.07166548028107, -26.73382008230491], [31.86806033705108, -27.177927341421277], [31.28277306491333, -27.285879408478998], [30.68596194837448, -26.743845310169533], [30.67660851412964, -26.398078301704608], [30.949666782359913, -26.02264902110415], [31.04407962415715, -25.731452325139443], [31.333157586397903, -25.66019052500895], [31.83777794772806, -25.84333180105135], [31.98577924981197, -26.291779880480227], [32.07166548028107, -26.73382008230491]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"MultiPolygon\", \"coordinates\": [[[[12.995517205465177, -4.781103203961884], [12.63161176926579, -4.991271254092936], [12.468004184629736, -5.248361504745005], [12.436688266660868, -5.6843038875592455], [12.182336866920252, -5.789930515163839], [11.91496300624209, -5.037986748884791], [12.318607618873926, -4.606230157086188], [12.620759718484493, -4.438023369976136], [12.995517205465177, -4.781103203961884]]], [[[12.32243167486351, -6.10009246177966], [12.735171339578699, -5.965682061388499], [13.024869419006961, -5.984388929878158], [13.375597364971895, -5.8642412247995495], [16.326528354567046, -5.877470391466268], [16.573179965896145, -6.6226445451150875], [16.8601908708452, -7.2222978654299865], [17.08999596524717, -7.545688978712526], [17.472970004962235, -8.0685511206417], [18.13422163256905, -7.987677504104923], [18.464175652752687, -7.847014255406443], [19.01675174324967, -7.988245944860132], [19.16661339689611, -7.738183688999754], [19.41750247567316, -7.155428562044299], [20.037723016040218, -7.116361179231646], [20.091621534920648, -6.943090101756994], [20.6018229509383, -6.939317722199682], [20.5147481625265, -7.2996058081386295], [21.7281107927397, -7.290872491081302], [21.74645592620331, -7.920084730667149], [21.949130893652043, -8.305900974158277], [21.8018013851879, -8.90870655684298], [21.875181919042348, -9.523707777548566], [22.208753289486395, -9.894796237836509], [22.155268182064308, -11.084801120653772], [22.402798292742375, -10.993075453335692], [22.83734541188474, -11.01762175867433], [23.45679080576744, -10.867863457892483], [23.912215203555718, -10.926826267137514], [24.01789350759259, -11.23729827234709], [23.904153680118185, -11.722281589406322], [24.079905226342845, -12.191296888887365], [23.930922072045377, -12.565847670138856], [24.016136508894675, -12.911046237848574], [21.933886346125917, -12.898437188369359], [21.887842644953874, -16.08031015387688], [22.56247846852426, -16.898451429921813], [23.215048455506064, -17.523116143465984], [21.377176141045567, -17.930636488519696], [18.956186964603603, -17.789094740472258], [18.263309360434164, -17.309950860262006], [14.209706658595024, -17.35310068122572], [14.05850141770901, -17.423380629142663], [13.462362094789967, -16.971211846588773], [12.814081251688407, -16.94134286872407], [12.215461460019355, -17.111668389558083], [11.734198846085121, -17.301889336824473], [11.64009606288161, -16.67314218512925], [11.778537224991537, -15.793816013250735], [12.12358076340439, -14.878316338767904], [12.175618930722294, -14.449143568583892], [12.50009524908299, -13.54769988368445], [12.738478631245385, -13.137905775609902], [13.312913852601866, -12.483630466362492], [13.6337211442698, -12.03864470789717], [13.738727654686897, -11.297863050993165], [13.686379428775238, -10.73107594161589], [13.387327915102162, -10.373578383020714], [13.120987583069846, -9.766897067914122], [12.875369500386569, -9.166933689005468], [12.92906131353783, -8.959091078327553], [13.236432732809874, -8.562629489784307], [12.93304039882429, -7.596538588087733], [12.728298374083892, -6.927122084178805], [12.227347039446471, -6.294447523629394], [12.32243167486351, -6.10009246177966]]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[30.469673645761223, -2.41385475710134], [30.527660000000026, -2.807619999999986], [30.743010000000027, -3.034309999999948], [30.752240000000086, -3.3593099999999936], [30.505539999999996, -3.5685799999999404], [30.11632000000003, -4.090120000000013], [29.753512404099865, -4.452389418153302], [29.339997592900346, -4.4999834122940925], [29.276383904749053, -3.293907159034063], [29.024926385216787, -2.8392579077301576], [29.632176141078588, -2.917857761246097], [29.93835900240794, -2.348486830254238], [30.469673645761223, -2.41385475710134]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[49.54351891459575, -12.469832858940554], [49.808980747279094, -12.895284925999555], [50.056510857957164, -13.555761407121985], [50.21743126811407, -14.758788750876796], [50.47653689962553, -15.226512139550543], [50.377111443895956, -15.706069431219127], [50.20027469259318, -16.000263360256767], [49.86060550313868, -15.414252618066918], [49.67260664246086, -15.710203545802479], [49.863344354050156, -16.451036879138776], [49.77456424337271, -16.8750420060936], [49.49861209493412, -17.106035658438273], [49.435618523970305, -17.953064060134366], [49.041792433473944, -19.118781019774445], [48.54854088724801, -20.496888116134127], [47.93074913919867, -22.391501153251085], [47.54772342305131, -23.781958916928517], [47.095761346226595, -24.941629733990453], [46.282477654817086, -25.178462823184105], [45.40950768411045, -25.60143442149309], [44.833573846217554, -25.34610116953894], [44.03972049334976, -24.988345228782308], [43.76376834491117, -24.46067717864999], [43.697777540874455, -23.574116306250602], [43.345654331237625, -22.776903985283873], [43.254187046081, -22.057413018484123], [43.43329756040464, -21.33647511158019], [43.893682895692926, -21.16330738697013], [43.896370070172104, -20.830459486578174], [44.37432539243966, -20.07236622485639], [44.46439741392439, -19.435454196859048], [44.23242190936617, -18.961994724200906], [44.042976108584156, -18.33138722094317], [43.96308434426091, -17.409944756746782], [44.31246870298628, -16.850495700754955], [44.4465173683514, -16.216219170804507], [44.94493655780653, -16.1793738745804], [45.50273196796499, -15.97437346767854], [45.87299360533626, -15.793454278224687], [46.31224327981721, -15.780018405828798], [46.882182651564285, -15.210182386946315], [47.70512983581236, -14.594302666891764], [48.005214878131255, -14.091232598530375], [47.869047479042166, -13.663868503476586], [48.29382775248138, -13.784067884987486], [48.84506025573879, -13.089174899958664], [48.86350874206698, -12.48786793381042], [49.194651320193316, -12.04055673589197], [49.54351891459575, -12.469832858940554]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[-16.71372880702347, 13.594958604379855], [-15.624596320039942, 13.62358734786956], [-15.39877031092446, 13.86036876063092], [-15.08173539881382, 13.876491807505985], [-14.687030808968487, 13.630356960499784], [-14.376713833055788, 13.625680243377374], [-14.046992356817482, 13.79406789800045], [-13.844963344772408, 13.505041612192002], [-14.277701788784555, 13.280585028532244], [-14.712197231494628, 13.298206691943777], [-15.141163295949468, 13.509511623585238], [-15.511812506562933, 13.278569647672867], [-15.691000535534995, 13.270353094938457], [-15.931295945692211, 13.130284125211332], [-16.841524624081273, 13.15139394780256], [-16.71372880702347, 13.594958604379855]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[9.482139926805274, 30.307556057246188], [9.05560265466815, 32.10269196220129], [8.439102817426118, 32.50628489840082], [8.430472853233368, 32.74833730725595], [7.6126416357821824, 33.34411489514896], [7.524481642292244, 34.09737641045146], [8.140981479534304, 34.65514598239379], [8.376367628623768, 35.479876003555944], [8.217824334352315, 36.433176988260286], [8.420964389691676, 36.94642731378316], [9.509993523810607, 37.349994411766545], [10.210002475636317, 37.230001735984814], [10.180650262094531, 36.724037787415085], [11.02886722173335, 37.09210317641396], [11.100025668999251, 36.899996039368915], [10.600004510143094, 36.410000108377375], [10.593286573945138, 35.94744436293281], [10.939518670300687, 35.698984076473494], [10.807847120821009, 34.83350718844919], [10.149592726287125, 34.33077301689771], [10.339658644256616, 33.78574168551532], [10.856836378633687, 33.76874013929128], [11.108500603895122, 33.293342800422195], [11.488787469131012, 33.13699575452324], [11.432253452203696, 32.368903103152874], [10.944789666394456, 32.081814683555365], [10.636901482799487, 31.761420803345757], [9.950225050505082, 31.376069647745258], [10.056575148161699, 30.961831366493527], [9.970017124072854, 30.53932485607524], [9.482139926805274, 30.307556057246188]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[-8.684399786809053, 27.395744126896005], [-8.665124477564191, 27.589479071558227], [-8.665589565454809, 27.656425889592356], [-8.674116176782974, 28.84128896739658], [-7.059227667661958, 29.5792284205246], [-6.060632290053774, 29.731699734001694], [-5.242129278982787, 30.00044302013559], [-4.859646165374471, 30.501187649043846], [-3.6904410465547244, 30.896951605751156], [-3.647497931320146, 31.637294012980675], [-3.068980271812648, 31.724497992473218], [-2.616604783529567, 32.09434621838619], [-1.30789913573787, 32.2628889023061], [-1.1245511539663084, 32.65152151135713], [-1.388049282222596, 32.86401500094138], [-1.7334545556614671, 33.91971283623212], [-1.792985805661715, 34.527918606091305], [-2.169913702798624, 35.16839630791668], [-1.208602871089056, 35.7148487411871], [-0.12745439289460592, 35.888662421200806], [0.5038765804152092, 36.30127289483528], [1.466918572606545, 36.605647081034405], [3.1616988460508253, 36.78390493422522], [4.81575809084913, 36.86503693292346], [5.3201200700177935, 36.71651886651662], [6.261819695672613, 37.11065501560674], [7.330384962603971, 37.11838064223437], [7.737078484741005, 36.885707505840216], [8.420964389691676, 36.94642731378316], [8.217824334352315, 36.433176988260286], [8.376367628623768, 35.479876003555944], [8.140981479534304, 34.65514598239379], [7.524481642292244, 34.09737641045146], [7.6126416357821824, 33.34411489514896], [8.430472853233368, 32.74833730725595], [8.439102817426118, 32.50628489840082], [9.05560265466815, 32.10269196220129], [9.482139926805274, 30.307556057246188], [9.805634392952356, 29.424638373323376], [9.859997999723447, 28.959989732371014], [9.683884718472768, 28.1441738957792], [9.756128370816782, 27.688258571884205], [9.629056023811074, 27.14095347748092], [9.716285841519664, 26.512206325785655], [9.319410841518163, 26.094324856057455], [9.910692579801776, 25.365454616796796], [9.94826134607797, 24.936953640232517], [10.303846876678362, 24.379313259370917], [10.771363559622927, 24.56253205006175], [11.560669386449005, 24.097909247325518], [11.999505649471613, 23.47166840259645], [8.572893100629784, 21.565660712159143], [5.677565952180686, 19.601206976799716], [4.267419467800039, 19.155265204337], [3.158133172222705, 19.057364203360038], [3.1466610042539003, 19.693578599521445], [2.683588494486429, 19.856230170160117], [2.06099083823392, 20.142233384679486], [1.8232275732590324, 20.610809434486043], [-1.5500548974576134, 22.792665920497384], [-4.923337368174231, 24.974574082941], [-8.684399786809053, 27.395744126896005]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[36.42951000000005, 14.422110000000032], [36.32321999999999, 14.822490000000016], [36.75389000000007, 16.291860000000042], [36.852530000000115, 16.956549999999993], [37.167470000000094, 17.263140000000135], [37.90400000000011, 17.427540000000022], [38.410089959473225, 17.998307399970315], [38.990622999840014, 16.840626125551694], [39.26611006038803, 15.92272349696725], [39.814293654140215, 15.435647284400318], [41.17927493669765, 14.491079616753211], [41.73495161313235, 13.921036892141558], [42.27683068214486, 13.343992010954423], [42.58957645037526, 13.000421250861905], [43.08122602720016, 12.699638576707116], [42.77964236834475, 12.455415757695675], [42.35156000000012, 12.542230000000131], [42.00975, 12.865819999999928], [41.59856000000002, 13.452090000000112], [41.15519999999998, 13.773329999999987], [40.896600000000035, 14.118640000000141], [40.02625000000012, 14.519589999999994], [39.34061000000008, 14.531549999999982], [39.0994, 14.740640000000042], [38.512950000000046, 14.50547000000006], [37.90607000000011, 14.959430000000168], [37.59377000000006, 14.213099999999997], [36.42951000000005, 14.422110000000032]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[-2.169913702798624, 35.16839630791668], [-1.792985805661715, 34.527918606091305], [-1.7334545556614671, 33.91971283623212], [-1.388049282222596, 32.86401500094138], [-1.1245511539663084, 32.65152151135713], [-1.30789913573787, 32.2628889023061], [-2.616604783529567, 32.09434621838619], [-3.068980271812648, 31.724497992473218], [-3.647497931320146, 31.637294012980675], [-3.6904410465547244, 30.896951605751156], [-4.859646165374471, 30.501187649043846], [-5.242129278982787, 30.00044302013559], [-6.060632290053774, 29.731699734001694], [-7.059227667661958, 29.5792284205246], [-8.674116176782974, 28.84128896739658], [-8.665589565454809, 27.656425889592356], [-8.817828334986672, 27.656425889592356], [-8.794883999049077, 27.120696316022507], [-9.41303748212448, 27.088476060488574], [-9.735343390328879, 26.860944729107405], [-10.189424200877582, 26.860944729107405], [-10.551262579785273, 26.990807603456886], [-11.392554897497007, 26.883423977154393], [-11.718219773800357, 26.104091701760623], [-12.03075883630163, 26.030866197203068], [-12.50096269372537, 24.7701162785782], [-13.891110398809047, 23.691009019459305], [-14.221167771857253, 22.31016307218816], [-14.630832688851072, 21.860939846274903], [-14.750954555713534, 21.500600083903663], [-17.00296179856109, 21.420734157796577], [-17.02042843267577, 21.422310288981578], [-16.973247849993243, 21.885744533774982], [-16.589136928767687, 22.158234361250095], [-16.261921759495635, 22.679339504481277], [-16.3264139469959, 23.017768459560898], [-15.982610642958036, 23.723358466074046], [-15.426003790742186, 24.35913361256104], [-15.089331834360735, 24.520260728447], [-14.824645148161665, 25.103532619725343], [-14.800925665739726, 25.63626496022232], [-14.439939947964831, 26.254418443297652], [-13.773804897506466, 26.618892320252314], [-13.13994177901435, 27.640147813420526], [-13.121613369914769, 27.65414767171984], [-12.618836635783111, 28.03818553314869], [-11.688919236690765, 28.148643907172527], [-10.900956997104402, 28.83214223888092], [-10.399592251008642, 29.09858592377782], [-9.564811163765683, 29.93357371674989], [-9.814718390329176, 31.17773550060906], [-9.434793260119363, 32.038096421836485], [-9.300692918321886, 32.564679266890664], [-8.657476365585012, 33.240245266242425], [-7.6541784326382185, 33.69706492770251], [-6.912544114601417, 34.110476386037476], [-6.2443420068514115, 35.145865383437524], [-5.92999426921989, 35.75998810479399], [-5.193863491222032, 35.75518219659085], [-4.591006232105144, 35.330711981745594], [-3.640056525070065, 35.399855048152006], [-2.604305792644084, 35.179093329401155], [-2.169913702798624, 35.16839630791668]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[36.86622999999997, 22.0], [32.89999999999998, 22.0], [29.019999999999982, 22.0], [25.0, 22.0], [25.0, 25.682499996361], [25.0, 29.23865452953346], [24.70007, 30.044190000000004], [24.957620000000002, 30.6616], [24.802869999999984, 31.089290000000005], [25.16482, 31.56915], [26.49533, 31.58568], [27.457620000000002, 31.32126], [28.450480000000002, 31.025769999999998], [28.913529999999998, 30.87005], [29.683419999999998, 31.186860000000003], [30.09503, 31.4734], [30.976930000000003, 31.55586], [31.687960000000004, 31.4296], [31.96041, 30.933600000000002], [32.19247, 31.26034], [32.99392, 31.024070000000002], [33.7734, 30.967460000000003], [34.26543474464621, 31.21935730952032], [34.265440000000005, 31.219359999999998], [34.823243288783814, 29.76108076171822], [34.9226, 29.50133], [34.64174, 29.099420000000002], [34.42655, 28.343989999999998], [34.15451, 27.8233], [33.92136, 27.6487], [33.58811, 27.97136], [33.13676, 28.417650000000002], [32.423230000000004, 29.851080000000003], [32.32046, 29.76043], [32.73482, 28.70523], [33.34876, 27.69989], [34.10455, 26.14227], [34.473870000000005, 25.598560000000003], [34.79507, 25.03375], [35.69241, 23.92671], [35.49372, 23.752370000000003], [35.52598, 23.10244], [36.690690000000004, 22.20485], [36.86622999999997, 22.0]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[25.0, 22.0], [25.000000000000114, 20.003040000000055], [23.850000000000136, 20.000000000000057], [23.83766000000014, 19.580470000000105], [19.849260000000072, 21.49509000000006], [15.860850000000084, 23.409719999999993], [14.851300000000037, 22.862950000000126], [14.143870883855243, 22.491288967371133], [13.581424594790462, 23.04050608976928], [11.999505649471613, 23.47166840259645], [11.560669386449005, 24.097909247325518], [10.771363559622927, 24.56253205006175], [10.303846876678362, 24.379313259370917], [9.94826134607797, 24.936953640232517], [9.910692579801776, 25.365454616796796], [9.319410841518163, 26.094324856057455], [9.716285841519664, 26.512206325785655], [9.629056023811074, 27.14095347748092], [9.756128370816782, 27.688258571884205], [9.683884718472768, 28.1441738957792], [9.859997999723447, 28.959989732371014], [9.805634392952356, 29.424638373323376], [9.482139926805274, 30.307556057246188], [9.970017124072854, 30.53932485607524], [10.056575148161699, 30.961831366493527], [9.950225050505082, 31.376069647745258], [10.636901482799487, 31.761420803345757], [10.944789666394456, 32.081814683555365], [11.432253452203696, 32.368903103152874], [11.488787469131012, 33.13699575452324], [12.663310000000024, 32.79278000000005], [13.083260000000053, 32.878820000000076], [13.918679999999995, 32.71196000000009], [15.245630000000006, 32.26508000000007], [15.713939999999923, 31.376259999999945], [16.611620000000016, 31.18217999999996], [18.02108999999996, 30.76356999999996], [19.08641, 30.26639], [19.574040000000082, 30.52582000000001], [20.053349999999966, 30.985760000000028], [19.82033000000007, 31.751790000000142], [20.13396999999992, 32.238200000000006], [20.854520000000093, 32.70679999999999], [21.54298, 32.843200000000024], [22.895760000000053, 32.63857999999999], [23.236800000000017, 32.191490000000044], [23.609130000000107, 32.18725999999998], [23.92750000000001, 32.01667000000009], [24.921139999999923, 31.89936], [25.16482, 31.56915], [24.802869999999984, 31.089290000000005], [24.957620000000002, 30.6616], [24.70007, 30.044190000000004], [25.0, 29.23865452953346], [25.0, 25.682499996361], [25.0, 22.0]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[47.78942, 8.003], [44.96360000000001, 5.00162], [43.66086999999999, 4.957550000000083], [42.76967, 4.25259], [42.128609999999995, 4.23413], [41.85508309264397, 3.918911920483727], [41.1718, 3.9190899999999997], [40.76848, 4.257020000000001], [39.85494, 3.83879], [39.55938425876585, 3.42206], [38.89251, 3.5007400000000004], [38.67114, 3.6160700000000006], [38.43697, 3.58851], [38.120915, 3.598605], [36.85509323800812, 4.447864127672769], [36.159078632855646, 4.447864127672769], [35.817447662353516, 4.7769656634618896], [35.817447662353516, 5.338232082790797], [35.29800711823298, 5.506], [34.70702, 6.594220000000121], [34.250320000000045, 6.8260700000000725], [34.07510000000002, 7.2259500000000685], [33.568290000000104, 7.7133400000000165], [32.954180000000065, 7.784970000000101], [33.29480000000012, 8.354580000000055], [33.82550000000015, 8.37916000000007], [33.97498000000007, 8.68455999999992], [33.961620000000096, 9.583580000000097], [34.25745000000006, 10.630089999999996], [34.73115000000013, 10.910170000000107], [34.83163000000013, 11.318960000000118], [35.26049000000006, 12.08286000000004], [35.86363, 12.578280000000063], [36.27022000000005, 13.563330000000121], [36.42951000000005, 14.422110000000032], [37.59377000000006, 14.213099999999997], [37.90607000000011, 14.959430000000168], [38.512950000000046, 14.50547000000006], [39.0994, 14.740640000000042], [39.34061000000008, 14.531549999999982], [40.02625000000012, 14.519589999999994], [40.896600000000035, 14.118640000000141], [41.15519999999998, 13.773329999999987], [41.59856000000002, 13.452090000000112], [42.00975, 12.865819999999928], [42.35156000000012, 12.542230000000131], [42.000000000000114, 12.100000000000136], [41.66176000000013, 11.631199999999978], [41.73959000000019, 11.355110000000138], [41.755570000000205, 11.050910000000101], [42.31414000000012, 11.034200000000055], [42.55493000000013, 11.105110000000195], [42.77685184100096, 10.92687856693442], [42.55875999999995, 10.57258000000013], [42.92812000000009, 10.021940000000143], [43.29699000000011, 9.540480000000173], [43.678750000000036, 9.18358000000012], [46.94834000000009, 7.99688000000009], [47.78942, 8.003]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[42.35156000000012, 12.542230000000131], [42.77964236834475, 12.455415757695675], [43.08122602720016, 12.699638576707116], [43.31785241066467, 12.390148423711025], [43.286381463398925, 11.974928290245884], [42.715873650896526, 11.735640570518342], [43.14530480324214, 11.462039699748857], [42.77685184100096, 10.92687856693442], [42.55493000000013, 11.105110000000195], [42.31414000000012, 11.034200000000055], [41.755570000000205, 11.050910000000101], [41.73959000000019, 11.355110000000138], [41.66176000000013, 11.631199999999978], [42.000000000000114, 12.100000000000136], [42.35156000000012, 12.542230000000131]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[48.94820475850985, 11.41061728169797], [48.94820475850974, 11.410617281697963], [48.94200524271835, 11.394266058798138], [48.938491245322496, 10.982327378783467], [48.93823286316103, 9.973500067581512], [48.93812951029645, 9.451748968946617], [48.48673587422695, 8.837626247589995], [47.78942, 8.003], [46.94834000000009, 7.99688000000009], [43.678750000000036, 9.18358000000012], [43.29699000000011, 9.540480000000173], [42.92812000000009, 10.021940000000143], [42.55875999999995, 10.57258000000013], [42.77685184100096, 10.92687856693442], [43.14530480324214, 11.462039699748857], [43.470659620951665, 11.277709865763882], [43.66666832863484, 10.86416921634816], [44.11780358254282, 10.445538438351605], [44.614259067570856, 10.442205308468942], [45.55694054543915, 10.698029486529776], [46.645401238803004, 10.816549383991173], [47.525657586462785, 11.12722809492999], [48.02159630716778, 11.193063869669743], [48.37878380716927, 11.375481675660126], [48.94820641459347, 11.41062164961852], [48.94820475850985, 11.41061728169797]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[33.90371119710453, -0.9500000000000001], [31.866170000000068, -1.0273599999999306], [30.769860000000108, -1.0145499999999856], [30.419104852019245, -1.1346591121504161], [29.821518588996014, -1.4433224422297855], [29.579466180140884, -1.3413131648856265], [29.58783776217217, -0.587405694179381], [29.819503208136638, -0.2053101538133717], [29.875778842902434, 0.5973798689763612], [30.086153598762706, 1.0623127303062887], [30.46850752129029, 1.5838054467797065], [30.85267011894806, 1.8493964705438088], [31.174149204235817, 2.204465236821264], [30.77334679538004, 2.339883327642127], [30.83385989759381, 3.509165961110341], [30.833852421715427, 3.5091716042224625], [31.24556000000007, 3.7819000000000074], [31.881449999999973, 3.558269999999993], [32.686420000000055, 3.7923200000000747], [33.3900000000001, 3.7899999999999636], [34.005, 4.249884947362048], [34.47913, 3.5556000000000836], [34.59607, 3.0537400000001185], [35.03599, 1.90584], [34.6721, 1.1769399999999999], [34.18, 0.515], [33.893568969666944, 0.1098135378618963], [33.90371119710453, -0.9500000000000001]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[30.419104852019245, -1.1346591121504161], [30.816134881317712, -1.6989140763453887], [30.75830895358311, -2.2872502579883687], [30.469670000000008, -2.4138299999999617], [30.469673645761223, -2.41385475710134], [29.93835900240794, -2.348486830254238], [29.632176141078588, -2.917857761246097], [29.024926385216787, -2.8392579077301576], [29.117478875451553, -2.2922111954883846], [29.254834832483343, -2.2151099585089113], [29.291886834436614, -1.6200558406679872], [29.579466180140884, -1.3413131648856265], [29.821518588996014, -1.4433224422297855], [30.419104852019245, -1.1346591121504161]]]}}, {\"CONTINENT\": \"Africa\", \"type\": \"Feature\", \"geometry\": {\"type\": \"Polygon\", \"coordinates\": [[[30.833852421715427, 3.5091716042224625], [29.953500197069474, 4.173699042167684], [29.71599531425602, 4.600804755060153], [29.1590784034465, 4.389267279473231], [28.696677687298802, 4.455077215996937], [28.428993768026913, 4.287154649264494], [27.97997724784281, 4.408413397637375], [27.37422610851749, 5.233944403500061], [27.21340905122517, 5.5509534773945575], [26.465909458123235, 5.9467174341018705], [26.213418409945117, 6.546603298362072], [25.79664798351118, 6.979315904158071], [25.124130893664727, 7.500085150579437], [25.11493248871679, 7.825104071479174], [24.567369012152085, 8.229187933785468], [23.886979580860668, 8.619729712933065], [24.19406772118765, 8.728696472403897], [24.53741516360202, 8.91753756573172], [24.794925745412684, 9.810240916008695], [25.069603699343986, 10.273759963267992], [25.790633328413946, 10.411098940233728], [25.962307049621018, 10.136420986302426], [26.477328213242515, 9.552730334198088], [26.752006167173818, 9.466893473594496], [27.112520981708883, 9.638567194801624], [27.833550610778786, 9.60423245056029], [27.970889587744352, 9.398223985111656], [28.966597170745786, 9.398223985111656], [29.000931914987177, 9.60423245056029], [29.515953078608618, 9.793073543888056], [29.61895731133285, 10.084918869940225], [29.996639497988554, 10.290927335388687], [30.837840731903384, 9.70723668328452], [31.35286189552488, 9.810240916008695], [31.850715687025513, 10.531270545078826], [32.400071594888345, 11.080626452941488], [32.31423473428475, 11.68148447716652], [32.073891524594785, 11.973329803218519], [32.67474954881965, 12.02483191958072], [32.743419037302544, 12.248007757149992], [33.206938084561784, 12.179338268667095], [33.086766479716744, 11.441141267476496], [33.206938084561784, 10.720111638406593], [33.72195924818311, 10.325262079630193], [33.84213085302815, 9.981914637215993], [33.82496348090751, 9.484060845715362], [33.963392794971185, 9.464285229420625], [33.97498000000007, 8.68455999999992], [33.82550000000015, 8.37916000000007], [33.29480000000012, 8.354580000000055], [32.954180000000065, 7.784970000000101], [33.568290000000104, 7.7133400000000165], [34.07510000000002, 7.2259500000000685], [34.250320000000045, 6.8260700000000725], [34.70702, 6.594220000000121], [35.29800711823298, 5.506], [34.62019626785388, 4.8471227420819885], [34.005, 4.249884947362048], [33.3900000000001, 3.7899999999999636], [32.686420000000055, 3.7923200000000747], [31.881449999999973, 3.558269999999993], [31.24556000000007, 3.7819000000000074], [30.833852421715427, 3.5091716042224625]]]}}], \"empty\": [{}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "execution_count": 3,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "gdf_ne = gpd.read_file(\"https://naciscdn.org/naturalearth/110m/cultural/ne_110m_admin_0_countries.zip\")  # zipped shapefile\n",
    "extent_roi = gdf_ne.loc[gdf_ne[\"CONTINENT\"] == \"Africa\", [\"CONTINENT\", \"geometry\"]]\n",
    "\n",
    "chart = (\n",
    "    alt.Chart(extent_roi)\n",
    "    .mark_geoshape(fillOpacity=0.1, stroke=\"green\", strokeWidth=2)\n",
    "    .project(type=\"mercator\")\n",
    ")\n",
    "til.add_tiles(chart).properties(width=600, height=400)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": ".venv",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.10.8"
  },
  "orig_nbformat": 4
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
